@@ -1,9 +1,6 @@
 OC.L10N.register(
     "files",
     {
-    "Storage is temporarily not available" : "Speicher ist vorübergehend nicht verfügbar",
-    "Storage invalid" : "Speicher ungültig",
-    "Unknown error" : "Unbekannter Fehler",
     "File could not be found" : "Datei konnte nicht gefunden werden",
     "Move or copy" : "Verschieben oder kopieren",
     "Download" : "Herunterladen",
@@ -17,7 +14,7 @@ OC.L10N.register(
     "Could not create folder \"{dir}\"" : "Der Ordner konnte nicht erstellt werden \"{dir}\"",
     "This will stop your current uploads." : "Hiermit werden die aktuellen Uploads angehalten.",
     "Upload cancelled." : "Hochladen abgebrochen.",
-    "Processing files …" : "Dateien werden verarbeitet…",
+    "Processing files …" : "Dateien werden verarbeitet …",
     "…" : "…",
     "Unable to upload {filename} as it is a directory or has 0 bytes" : "Die Datei {filename} kann nicht hochgeladen werden, da sie entweder ein Verzeichnis oder 0 Bytes groß ist",
     "Not enough free space, you are uploading {size1} but only {size2} is left" : "Nicht genügend freier Speicherplatz, du möchtest{size1} hochladen, es sind jedoch nur noch {size2} verfügbar.",
@@ -25,7 +22,7 @@ OC.L10N.register(
     "Not enough free space" : "Nicht genügend freier Speicherplatz",
     "An unknown error has occurred" : "Es ist ein unbekannter Fehler aufgetreten",
     "File could not be uploaded" : "Datei konnte nicht hochgeladen werden.",
-    "Uploading …" : "Lade hoch…",
+    "Uploading …" : "Lade hoch …",
     "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} von {totalSize} ({bitrate})",
     "Uploading that item is not supported" : "Hochladen von Daten dieser Art wird nicht unterstützt.",
     "Target folder does not exist any more" : "Zielordner existiert nicht mehr",
@@ -36,6 +33,7 @@ OC.L10N.register(
     "Move" : "Verschieben",
     "Copy" : "Kopieren",
     "Choose target folder" : "Zielordner wählen",
+    "Edit locally" : "Lokal bearbeiten",
     "Open" : "Öffnen",
     "Delete file" : "Datei löschen",
     "Delete folder" : "Ordner löschen",
@@ -52,6 +50,7 @@ OC.L10N.register(
     "Unable to determine date" : "Datum konnte nicht ermittelt werden",
     "This operation is forbidden" : "Diese Operation ist nicht erlaubt",
     "This directory is unavailable, please check the logs or contact the administrator" : "Dieses Verzeichnis ist nicht verfügbar, bitte die Logdateien überprüfen oder den Administrator kontaktieren.",
+    "Storage is temporarily not available" : "Speicher ist vorübergehend nicht verfügbar",
     "Could not move \"{file}\", target exists" : "\"{file}\" konnte nicht verschoben werden, Ziel existiert bereits",
     "Could not move \"{file}\"" : "\"{file}\" konnte nicht verschoben werden",
     "copy" : "Kopie",
@@ -59,6 +58,7 @@ OC.L10N.register(
     "Could not copy \"{file}\"" : "\"{file}\" konnte nicht kopiert werden",
     "Copied {origin} inside {destination}" : "{origin} wurde nach {destination} kopiert",
     "Copied {origin} and {nbfiles} other files inside {destination}" : "{origin} und {nbfiles} weitere Dateien wurden nach {destination} kopiert",
+    "Failed to redirect to client" : "Umleitung zum Client fehlgeschlagen",
     "{newName} already exists" : "{newName} existiert bereits",
     "Could not rename \"{fileName}\", it does not exist any more" : "Die Datei \"{fileName}\" konnte nicht umbenannt werden, da sie nicht mehr existiert",
     "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Der Name „{targetName}“ wird bereits im Ordner „{dir}“ benutzt. Bitte einen anderen Namen verwenden.",
@@ -79,6 +79,7 @@ OC.L10N.register(
     "_including %n hidden_::_including %n hidden_" : ["%n versteckte eingeschlossen","%n versteckte eingeschlossen"],
     "You do not have permission to upload or create files here" : "Du hast keine Berechtigung, hier Dateien hochzuladen oder zu erstellen",
     "_Uploading %n file_::_Uploading %n files_" : ["%n Datei wird hochgeladen","%n Dateien werden hochgeladen"],
+    "New file/folder menu" : "Menü für neue Datei/Ordner",
     "Select file range" : "Dateibereich auswählen",
     "{used}%" : "{used}%",
     "{used} of {quota} used" : "{used} von {quota} verwendet",
@@ -97,12 +98,12 @@ OC.L10N.register(
     "Your storage is almost full ({usedSpacePercent}%)." : "Dein Speicher ist beinahe voll ({usedSpacePercent}%).",
     "_matches \"{filter}\"_::_match \"{filter}\"_" : ["stimmt mit \"{filter}\" überein","stimmen mit \"{filter}\" überein"],
     "View in folder" : "In Ordner anzeigen",
-    "Copied!" : "Kopiert!",
-    "Copy direct link (only works for users who have access to this file/folder)" : "Direkten Link kopieren (funktioniert nur für Benutzer, die Zugriff auf diese(n) Datei/Ordner haben)",
+    "Direct link was copied (only works for users who have access to this file/folder)" : "Direktlink wurde kopiert (funktioniert nur für Benutzer, die Zugriff auf diese Datei/Ordner haben)",
     "Path" : "Pfad",
     "_%n byte_::_%n bytes_" : ["%n Byte","%n Bytes"],
     "Favorited" : "Favorisiert",
     "Favorite" : "Favorit",
+    "Copy direct link (only works for users who have access to this file/folder)" : "Direkten Link kopieren (funktioniert nur für Benutzer, die Zugriff auf diese(n) Datei/Ordner haben)",
     "You can only favorite a single file or folder at a time" : "Du kannst gleichzeitig nur eine Datei oder einen Ordner als Favorit markieren",
     "New folder" : "Neuer Ordner",
     "Upload file" : "Datei hochladen",
@@ -152,7 +153,6 @@ OC.L10N.register(
     "A file or folder has been <strong>changed</strong>" : "Eine Datei oder ein Ordner wurde <strong>geändert</strong>",
     "A favorite file or folder has been <strong>changed</strong>" : "Eine favorisierte Datei oder ein Ordner wurde <strong>geändert</strong>",
     "All files" : "Alle Dateien",
-    "Unlimited" : "Unbegrenzt",
     "Upload (max. %s)" : "Hochladen (max. %s)",
     "Accept" : "Akzeptieren",
     "Reject" : "Ablehnen",
@@ -166,6 +166,10 @@ OC.L10N.register(
     "The ownership transfer of {path} from {user} has completed." : "Die Besitzübertragung von {path} durch {user} wurde fertiggestellt.",
     "in %s" : "in %s",
     "File Management" : "Dateiverwaltung",
+    "Storage informations" : "Speicherinformationen",
+    "{usedQuotaByte} used" : "{usedQuotaByte} verwendet",
+    "{relative}% used" : "{relative}% verwendet",
+    "Could not refresh storage stats" : "Die Speicherstatistik konnte nicht aktualisiert werden",
     "Transfer ownership of a file or folder" : "Besitz einer Datei oder eines Ordners übertragen",
     "Choose file or folder to transfer" : "Datei oder Ordner zur Übertragung auswählen",
     "Change" : "Ändern",
@@ -175,8 +179,22 @@ OC.L10N.register(
     "Transfer" : "Übertragen",
     "Transfer {path} to {userid}" : "Übertrage {path} an {userid}",
     "Invalid path selected" : "Ungültiger Dateipfad ausgewählt",
+    "Unknown error" : "Unbekannter Fehler",
     "Ownership transfer request sent" : "Anforderung für die Übertragung des Besitzes gesendet",
     "Cannot transfer ownership of a file or folder you do not own" : "Der Besitz an einer Datei oder einem Ordner, der dir nicht gehört, kann nicht übertragen werden",
+    "Select file or folder to link to" : "Datei oder Ordner zum Verknüpfen auswählen",
+    "Open the files app settings" : "Einstellungen der Dateien-App öffnen",
+    "Files settings" : "Dateien-Einstellungen",
+    "File cannot be accessed" : "Auf die Datei kann nicht zugegriffen werden",
+    "You might not have have permissions to view it, ask the sender to share it" : "Möglicherweise hast du nicht die Berechtigung zur Anzeige. Bitte den Absender, die Datei freizugeben.",
+    "Show hidden files" : "Versteckte Dateien anzeigen",
+    "Crop image previews" : "Bildvorschauen zuschneiden",
+    "Additional settings" : "Zusätzliche Einstellungen",
+    "WebDAV" : "WebDAV",
+    "Copy to clipboard" : "In die Zwischenablage kopieren",
+    "Use this address to access your Files via WebDAV" : "Diese Adresse benutzen, um über WebDAV auf deine Dateien zuzugreifen",
+    "Clipboard is not available" : "Zwischenablage ist nicht verfügbar",
+    "WebDAV URL copied to clipboard" : "WebDAV-URL in die Zwischenablage kopiert",
     "Unable to change the favourite state of the file" : "Der favorisierte Status der Datei konnte nicht geändert werden",
     "Error while loading the file data" : "Fehler beim Laden der Datei-Daten",
     "Pick a template for {name}" : "Eine Vorlage für {name} wählen",
@@ -189,14 +207,6 @@ OC.L10N.register(
     "Set up templates folder" : "Vorlagenordner einrichten",
     "Templates" : "Vorlagen",
     "Unable to initialize the templates directory" : "Der Vorlagenordner konnte nicht initialisiert werden",
-    "%s used" : "%s verwendet",
-    "%s%%" : "%s%%",
-    "%1$s of %2$s used" : "%1$s von %2$s verwendet",
-    "Files settings" : "Dateien-Einstellungen",
-    "Show hidden files" : "Versteckte Dateien anzeigen",
-    "Crop image previews" : "Bildvorschauen zuschneiden",
-    "WebDAV" : "WebDAV",
-    "Use this address to access your Files via WebDAV" : "Diese Adresse benutzen, um über WebDAV auf deine Dateien zuzugreifen",
     "Toggle %1$s sublist" : "Unterliste %1$s umschalten",
     "Toggle grid view" : "Rasteransicht umschalten",
     "No files in here" : "Keine Dateien vorhanden",
@@ -216,11 +226,16 @@ OC.L10N.register(
     "Pending shares" : "Ausstehende Freigaben",
     "Text file" : "Textdatei",
     "New text file.txt" : "Neue Textdatei file.txt",
+    "Storage invalid" : "Speicher ungültig",
     "Select" : "Auswählen",
     "You don’t have permission to upload or create files here" : "Du hast keine Berechtigung, hier Dateien hochzuladen oder zu erstellen",
     "New" : "Neu",
+    "Copied!" : "Kopiert!",
+    "Unlimited" : "Unbegrenzt",
     "Cannot transfer ownership of a file or folder you don't own" : "Der Besitz einer Datei oder eines Ordners, den du nicht besitzt, kann nicht übertragen werden",
-    "%s%% of %s used" : "%s%% von %s verwendet",
+    "%s used" : "%s verwendet",
+    "%s%%" : "%s%%",
+    "%1$s of %2$s used" : "%1$s von %2$s verwendet",
     "Settings" : "Einstellungen"
 },
 "nplurals=2; plural=(n != 1);");
