@@ -1,9 +1,6 @@
 OC.L10N.register(
     "files",
     {
-    "Storage is temporarily not available" : "Le support de stockage est temporairement indisponible",
-    "Storage invalid" : "Support de stockage invalide",
-    "Unknown error" : "Erreur inconnue ",
     "File could not be found" : "Fichier introuvable",
     "Move or copy" : "Déplacer ou copier",
     "Download" : "Télécharger",
@@ -53,6 +50,7 @@ OC.L10N.register(
     "Unable to determine date" : "Impossible de déterminer la date",
     "This operation is forbidden" : "Cette opération est interdite",
     "This directory is unavailable, please check the logs or contact the administrator" : "Ce répertoire est indisponible, merci de consulter les journaux ou de contacter votre administrateur",
+    "Storage is temporarily not available" : "Le support de stockage est temporairement indisponible",
     "Could not move \"{file}\", target exists" : "Impossible de déplacer \"{file}\", la cible existe",
     "Could not move \"{file}\"" : "Impossible de déplacer \"{file}\"",
     "copy" : "copie",
@@ -100,12 +98,12 @@ OC.L10N.register(
     "Your storage is almost full ({usedSpacePercent}%)." : "Votre espace de stockage est presque plein ({usedSpacePercent}%).",
     "_matches \"{filter}\"_::_match \"{filter}\"_" : ["correspond à \"{filter}\"","correspondent à '{filter}'","correspondent à '{filter}'"],
     "View in folder" : "Afficher dans le dossier",
-    "Copied!" : "Copié !",
-    "Copy direct link (only works for users who have access to this file/folder)" : "Copier le Lien direct (fonctionne uniquement pour les utilisateurs autorisés à accéder à ce fichier ou à ce dossier)",
+    "Direct link was copied (only works for users who have access to this file/folder)" : "Le lien direct a été copié (fonctionne uniquement pour les utilisateurs qui ont accès à ce fichier/dossier)",
     "Path" : "Chemin",
     "_%n byte_::_%n bytes_" : ["%n octet","%n octets","%n octets"],
     "Favorited" : "Marqué comme favori",
     "Favorite" : "Favoris",
+    "Copy direct link (only works for users who have access to this file/folder)" : "Copier le Lien direct (fonctionne uniquement pour les utilisateurs autorisés à accéder à ce fichier ou à ce dossier)",
     "You can only favorite a single file or folder at a time" : "Vous ne pouvez ajouter qu'un seul favori de dossier ou de fichier à la fois.",
     "New folder" : "Nouveau dossier",
     "Upload file" : "Téléverser un fichier",
@@ -155,7 +153,6 @@ OC.L10N.register(
     "A file or folder has been <strong>changed</strong>" : "Un fichier ou un dossier a été <strong>modifié</strong>",
     "A favorite file or folder has been <strong>changed</strong>" : "Un fichier ou un dossier favori a été <strong>modifié </strong>",
     "All files" : "Tous les fichiers",
-    "Unlimited" : "Illimité",
     "Upload (max. %s)" : "Envoi (max. %s)",
     "Accept" : "Accepter",
     "Reject" : "Refuser",
@@ -169,6 +166,10 @@ OC.L10N.register(
     "The ownership transfer of {path} from {user} has completed." : "Le transfert de propriété de {path} de {user} est terminé.",
     "in %s" : "dans %s",
     "File Management" : "Gestion de fichier",
+    "Storage informations" : "Informations sur le stockage",
+    "{usedQuotaByte} used" : "{usedQuotaByte} utilisés",
+    "{relative}% used" : "{relative}% utilisés",
+    "Could not refresh storage stats" : "Impossible de rafraîchir les statistiques de stockage",
     "Transfer ownership of a file or folder" : "Transférer la propriété d'un fichier ou d'un dossier",
     "Choose file or folder to transfer" : "Sélectionnez un fichier ou un dossier à transférer",
     "Change" : "Modifier",
@@ -178,8 +179,23 @@ OC.L10N.register(
     "Transfer" : "Transférer",
     "Transfer {path} to {userid}" : "Transférer {path} à {userid}",
     "Invalid path selected" : "Chemin sélectionné non valide",
+    "Unknown error" : "Erreur inconnue ",
     "Ownership transfer request sent" : "Requête de transfert de propriété envoyée",
     "Cannot transfer ownership of a file or folder you do not own" : "Impossible de transférer la propriété d'un fichier ou d'un dossier que vous ne possédez pas",
+    "Select file or folder to link to" : "Sélectionnez le fichier ou le dossier à lier",
+    "Open the files app settings" : "Ouvrir les paramètres de l'application Fichiers",
+    "Files settings" : "Paramètres des fichiers",
+    "File cannot be accessed" : "Impossible d'accéder au fichier",
+    "You might not have have permissions to view it, ask the sender to share it" : "Vous n’avez peut-être pas les autorisations pour le voir, demandez à l’expéditeur de le partager.",
+    "Show hidden files" : "Afficher les fichiers masqués",
+    "Crop image previews" : "Afficher en miniatures carrées",
+    "Additional settings" : "Paramètres supplémentaires",
+    "WebDAV" : "WebDAV",
+    "Copy to clipboard" : "Copier dans le presse-papiers",
+    "Use this address to access your Files via WebDAV" : "Utilisez cette adresse pour accéder à vos fichiers via WebDAV",
+    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Si vous avez activé l'A2F, vous devez créer et utiliser un nouveau mot de passe d'application en cliquant ici.",
+    "Clipboard is not available" : "Le presse-papiers n'est pas disponible",
+    "WebDAV URL copied to clipboard" : "URL WebDAV copiée dans le presse-papier",
     "Unable to change the favourite state of the file" : "Impossible de modifier l'état favori du fichier",
     "Error while loading the file data" : "Erreur lors du chargement du fichier de données",
     "Pick a template for {name}" : "Choisissez un modèle pour {name}",
@@ -192,14 +208,6 @@ OC.L10N.register(
     "Set up templates folder" : "Configurer le dossier des modèles",
     "Templates" : "Modèles",
     "Unable to initialize the templates directory" : "Impossible d'initialiser le dossier des modèles",
-    "%s used" : "%s utilisés",
-    "%s%%" : "%s%%",
-    "%1$s of %2$s used" : "%1$s utilisés sur %2$s",
-    "Files settings" : "Paramètres des fichiers",
-    "Show hidden files" : "Afficher les fichiers masqués",
-    "Crop image previews" : "Activer l'affichage en miniatures carrées",
-    "WebDAV" : "WebDAV",
-    "Use this address to access your Files via WebDAV" : "Utilisez cette adresse pour accéder à vos fichiers via WebDAV",
     "Toggle %1$s sublist" : "Basculer %1$s sous-liste",
     "Toggle grid view" : "Activer/Désactiver l'affichage mosaïque",
     "No files in here" : "Aucun fichier",
@@ -219,11 +227,16 @@ OC.L10N.register(
     "Pending shares" : "Partages en attente",
     "Text file" : "Fichier texte",
     "New text file.txt" : "Nouveau fichier texte.txt",
+    "Storage invalid" : "Support de stockage invalide",
     "Select" : "Sélectionner",
     "You don’t have permission to upload or create files here" : "Vous n'avez pas la permission d'envoyer ou de créer des fichiers ici",
     "New" : "Nouveau",
+    "Copied!" : "Copié !",
+    "Unlimited" : "Illimité",
     "Cannot transfer ownership of a file or folder you don't own" : "Impossible de transférer la propriété d’un fichier ou d’un dossier dont vous n'êtes pas le propriétaire",
-    "%s%% of %s used" : "%s%% de %s utilisés",
+    "%s used" : "%s utilisés",
+    "%s%%" : "%s%%",
+    "%1$s of %2$s used" : "%1$s utilisés sur %2$s",
     "Settings" : "Paramètres"
 },
 "nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
