@@ -38,7 +38,8 @@ OC.L10N.register(
     "{actor} changed your email address" : "{actor} ändrade din e-postadress",
     "You changed your email address" : "Du ändrade din e-postadress",
     "Your email address was changed by an administrator" : "Din e-postadress ändrades av en administratör",
-    "You created app password \"{token}\"" : "Du skapade applösenord \"{token}\"",
+    "You created an app password for a session named \"{token}\"" : "Du skapade ett applösenord för en session med namnet \"{token}\"",
+    "An administrator created an app password for a session named \"{token}\"" : "En administratör skapade ett applösenord för en session med namnet \"{token}\"",
     "You deleted app password \"{token}\"" : "Du tog bort applösenordet \"{token}\"",
     "You renamed app password \"{token}\" to \"{newToken}\"" : "Du ändrade namn på applösenord \"{token}\" till \"{newToken}\"",
     "You granted filesystem access to app password \"{token}\"" : "Du tilldelade filsystem-åtkomst till applösenord \"{token}\"",
@@ -49,21 +50,40 @@ OC.L10N.register(
     "Remote wipe was started on %1$s" : "Fjärrensning startades på %1$s",
     "Remote wipe has finished on %1$s" : "Fjärrensning slutfördes på %1$s",
     "Your <strong>password</strong> or <strong>email</strong> was modified" : "Ditt <strong>lösenord</strong> eller <strong>e-postadress</strong> har ändrats",
+    "Apps" : "Appar",
+    "Could not remove app." : "Kunde inte ta bort app.",
+    "Could not update app." : "Kunde inte uppdatera app.",
     "Wrong password" : "Fel lösenord",
+    "Unable to change personal password" : "Kunde inte byta personligt lösenord",
     "Saved" : "Sparad",
     "No user supplied" : "Ingen användare angiven",
+    "Unable to change password. Password too long." : "Kunde inte byta lösenord. Lösenord för långt.",
     "Authentication error" : "Fel vid autentisering",
     "Please provide an admin recovery password; otherwise, all user data will be lost." : "Vänligen ange ett administratörs återställningslösenord; annars kommer alla användardata att försvinna.",
     "Wrong admin recovery password. Please check the password and try again." : "Felaktigt återställningslösenord för administratör. Kontrollera lösenordet och prova igen.",
+    "Backend does not support password change, but the user's encryption key was updated." : "Backend stödjer inte att lösenord ändras, men användarens krypteringsnyckel uppdaterades.",
     "installing and updating apps via the App Store or Federated Cloud Sharing" : "installera och uppdatera appar via appbutiken eller federerad molndelning",
     "Federated Cloud Sharing" : "Federerad Moln-delning",
     "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL använder en föråldrad %1$s version (%2$s). Uppdatera ditt operativsystem annars kommer inte funktioner som %3$s fungera pålitligt.",
+    "Could not determine if TLS version of cURL is outdated or not because an error happened during the HTTPS request against https://nextcloud.com. Please check the Nextcloud log file for more details." : "Kunde inte bestämma om TLS-versionen av cURL är för gammal eller inte för ett fel uppstod under HTTPS-förfrågan mot https://nextcloud.com. Vänligen kontrollera Nextcloud loggfilen för fler detaljer.",
+    "The PHP OPcache module is not loaded. For better performance it is recommended to load it into your PHP installation." : "PHP OPcache-modulen är inte laddad. För bättre prestanda rekommenderas det att ladda den i din PHP-installation.",
+    "OPcache is disabled. For better performance, it is recommended to apply <code>opcache.enable=1</code> to your PHP configuration." : "OPcache är inaktiverat. För bättre prestanda rekommenderas att lägga till <code>opcache.enable=1</code> i din PHP-konfiguration.",
+    "OPcache is configured to remove code comments. With OPcache enabled, <code>opcache.save_comments=1</code> must be set for Nextcloud to function." : "OPcache är konfigurerad för att ta bort kodkommentarer. Med OPcache aktiverat måste <code>opcache.save_comments=1</code> sättas för att Nextcloud ska fungera.",
+    "Nextcloud is not allowed to use the OPcache API. With OPcache enabled, it is highly recommended to include all Nextcloud directories with <code>opcache.restrict_api</code> or unset this setting to disable OPcache API restrictions, to prevent errors during Nextcloud core or app upgrades." : "Nextcloud får inte använda OPcache API. Med OPcache aktiverat rekommenderas det starkt att inkludera alla Nextcloud-kataloger med <code>opcache.restrict_api</code> eller avaktivera denna inställning för att inaktivera OPcache API-begränsningar, för att förhindra fel under Nextcloud kärna eller appuppgraderingar.",
+    "Nextcloud is not allowed to use the OPcache API. It is highly recommended to include all Nextcloud directories with <code>opcache.restrict_api</code> or unset this setting to disable OPcache API restrictions, to prevent errors during Nextcloud core or app upgrades." : "Nextcloud får inte använda OPcache API. Det rekommenderas starkt att inkludera alla Nextcloud-kataloger med <code>opcache.restrict_api</code> eller avaktivera denna inställning för att inaktivera OPcache API-begränsningar, för att förhindra fel under Nextcloud core eller appuppgraderingar.",
+    "The maximum number of OPcache keys is nearly exceeded. To assure that all scripts can be kept in the cache, it is recommended to apply <code>opcache.max_accelerated_files</code> to your PHP configuration with a value higher than <code>%s</code>." : "Det maximala antalet OPcache-nycklar har nästan överskridits. För att säkerställa att alla skript kan behållas i cachen, rekommenderas det att tillämpa <code>opcache.max_accelerated_files</code> i din PHP-konfiguration med ett värde högre än <code>%s</code>.",
+    "The OPcache buffer is nearly full. To assure that all scripts can be hold in cache, it is recommended to apply <code>opcache.memory_consumption</code> to your PHP configuration with a value higher than <code>%s</code>." : "OPcache-bufferten är nästan full. För att säkerställa att alla skript kan lagras i cache, rekommenderas det att tillämpa <code>opcache.memory_consumption</code> i din PHP-konfiguration med ett värde högre än <code>%s</code>.",
+    "The OPcache interned strings buffer is nearly full. To assure that repeating strings can be effectively cached, it is recommended to apply <code>opcache.interned_strings_buffer</code> to your PHP configuration with a value higher than <code>%s</code>." : "OPcachens internerade strängbuffert är nästan full. För att säkerställa att upprepade strängar effektivt kan cachelagras, rekommenderas det att använda <code>opcache.interned_strings_buffer</code> i din PHP-konfiguration med ett värde högre än <code>%s</code>.",
+    "Administrator documentation" : "Administratörsdokumentation",
+    "User documentation" : "Användardokumentation",
     "Invalid SMTP password." : "Ogiltigt SMTP-lösenord.",
     "Email setting test" : "E-postinställningar test",
     "Well done, %s!" : "Bra gjort, %s!",
     "If you received this email, the email configuration seems to be correct." : "Om du får detta e-postmeddelande så har du ställt in e-postinställningarna rätt.",
     "Email could not be sent. Check your mail server log" : "E-post kunde inte skickas. Titta i din e-postserverlogg",
     "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Ett problem uppstod när e-post försökte skickas. Kontrollera dina inställningar. (Fel: %s)",
+    "You need to set your user email before being able to send test emails. Go to %s for that." : "Du måste ställa in din användarmailadress innan du kan skicka testmail. Gå till %s för att göra det.",
+    "Users" : "Användare",
     "Invalid user" : "Ogiltig användare",
     "Invalid mail address" : "Ogiltig e-postadress",
     "Settings saved" : "Inställningar sparade",
@@ -95,7 +115,6 @@ OC.L10N.register(
     "Go to %s" : "Gå till %s",
     "Install Client" : "Installera Klient",
     "Logged in user must be a subadmin" : "Inloggad användare måste vara en del-administratör",
-    "Apps" : "Appar",
     "Settings" : "Inställningar",
     "Personal" : "Privat",
     "Administration" : "Administration",
@@ -106,6 +125,7 @@ OC.L10N.register(
     "Basic settings" : "Generella inställningar",
     "Sharing" : "Dela",
     "Availability" : "Tillgänglighet",
+    "Calendar" : "Kalender",
     "Personal info" : "Personlig information",
     "Mobile & desktop" : "Mobil & skrivbord",
     "Email server" : "E-postserver",
@@ -119,9 +139,15 @@ OC.L10N.register(
     "Verifying" : "Verifiera",
     "A background job is pending that checks for user imported SSL certificates. Please check back later." : "Ett bakgrundsjobb väntar som söker efter användarimporterade SSL-certifikat. Vänligen kontrollera igen senare.",
     "There are some user imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "Det finns några användarimporterade SSL-certifikat närvarande som inte längre används med Nextcloud 21. De kan importeras i kommandoraden via \"occ security:certificates:import\". Deras sökvägar inuti data-mappen visas nedanför.",
+    "Invalid UUIDs of LDAP users or groups have been found. Please review your \"Override UUID detection\" settings in the Expert part of the LDAP configuration and use \"occ ldap:update-uuid\" to update them." : "Ogiltiga UUID för LDAP-användare eller -grupper har hittats. Granska dina \"Åsidosätt UUID-detektering\"-inställningar i expertdelen av LDAP-konfigurationen och använd \"occ ldap:update-uuid\" för att uppdatera dem.",
     "The old server-side-encryption format is enabled. We recommend disabling this." : "Det gamla krypteringsformatet på servern är aktiverat. Vi rekommenderar att du inaktiverar detta.",
+    "MariaDB version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MariaDB 10.2 or higher." : "MariaDB version \"%s\" används. Nextcloud 21 och högre stöder inte denna version och kräver MariaDB 10.2 eller högre.",
+    "MySQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MySQL 8.0 or MariaDB 10.2 or higher." : "MySQL-versionen \"%s\" används. Nextcloud 21 och högre stöder inte denna version och kräver MySQL 8.0 eller MariaDB 10.2 eller högre.",
+    "PostgreSQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require PostgreSQL 9.6 or higher." : "PostgreSQL-versionen \"%s\" används. Nextcloud 21 och högre stöder inte denna version och kräver PostgreSQL 9.6 eller högre.",
+    "Profile information" : "Profilinformation",
+    "Profile picture, full name, email, phone number, address, website, Twitter, organisation, role, headline, biography, and whether your profile is enabled" : "Profilbild, fullständigt namn, e-post, telefonnummer, adress, webbplats, Twitter, organisation, roll, rubrik, biografi och om din profil är aktiverad",
     "Nextcloud settings" : "Nextcloud-inställningar",
-    "Here you can decide which group can access certain sections of the administration settings." : "Här kan du bestämma vilken gruppen som har tillgång till vissa delar av administrationsinställningarna.",
+    "Here you can decide which group can access certain sections of the administration settings." : "Här kan du bestämma vilken grupp som har tillgång till vissa delar av administrationsinställningarna.",
     "None" : "Ingen",
     "Unable to modify setting" : "Kunde inte ändra inställning.",
     "Two-Factor Authentication" : "Tvåfaktorsautentisering",
@@ -147,7 +173,6 @@ OC.L10N.register(
     "View in store" : "Visa i butik",
     "Visit website" : "Besök webbplats",
     "Report a bug" : "Rapportera ett problem",
-    "User documentation" : "Användardokumentation",
     "Admin documentation" : "Administratörsdokumentation",
     "Developer documentation" : "Utvecklardokumentation",
     "This app is supported via your current Nextcloud subscription." : "Den här appen stöds via ditt nuvarande Nextcloud-abonnemang.",
@@ -155,17 +180,20 @@ OC.L10N.register(
     "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Utvalda appar utvecklas av och inom gemenskapen. De erbjuder central funktionalitet och är redo för produktionsanvändning.",
     "Featured" : "Utvalda",
     "Update to {update}" : "Uppdatera till {update}",
+    "All apps are up-to-date." : "Alla appar är uppdaterade.",
     "Results from other categories" : "Resultat från andra kategorier",
     "No apps found for your version" : "Inga appar funna för din version",
     "Disable all" : "Inaktivera alla",
     "Enable all" : "Aktivera alla",
     "_%n app has an update available_::_%n apps have an update available_" : ["%n app har en uppdatering tillgänglig","%n appar har en uppdatering tillgänglig"],
+    "_Update_::_Update all_" : ["Uppdatera","Uppdatera alla"],
     "Marked for remote wipe" : "Markerad för fjärrensning",
     "Device settings" : "Enhetsinställningar",
     "Allow filesystem access" : "Tillåt åtkomst till filsystemet",
     "Rename" : "Byt namn",
     "Revoke" : "Återkalla",
     "Wipe device" : "Rensa enhet",
+    "Revoking this token might prevent the wiping of your device if it has not started the wipe yet." : "Återkallning kan förhindra att enheten rensas om inte rensningen redan har startat.",
     "Internet Explorer" : "Internet Explorer",
     "Edge" : "Edge",
     "Firefox" : "Firefox",
@@ -202,12 +230,27 @@ OC.L10N.register(
     "Copied!" : "Kopierad!",
     "Copy" : "Kopiera",
     "Could not copy app password. Please copy it manually." : "Det gick inte att kopiera applösenordet. Kopiera det manuellt.",
+    "For the server to work properly, it's important to configure background jobs correctly. Cron is the recommended setting. Please see the documentation for more information." : "För att servern ska fungera korrekt är det viktigt att konfigurera bakgrundsjobb korrekt. Cron är den rekommenderade inställningen. Se dokumentationen för mer information.",
+    "Last job execution ran {time}. Something seems wrong." : "Senaste jobbexekveringen kördes {time}. Något verkar vara fel.",
+    "Last job ran {relativeTime}." : "Senaste jobbet kördes {relativeTime}.",
+    "Background job did not run yet!" : "Bakgrundsjobb har inte kört ännu!",
+    "AJAX" : "AJAX",
+    "Execute one task with each page loaded. Use case: Single user instance." : "Utför en uppgift med varje sidladdning. Användningsfall: instans med en användare.",
+    "Webcron" : "Webcron",
+    "cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP. Use case: Very small instance (1–5 users depending on the usage)." : "cron.php är registrerad på en webcron-tjänst för att anropa cron.php var 5:e minut över HTTP. Användningsfall: Mycket liten instans (1–5 användare beroende på användning).",
+    "Cron (Recommended)" : "Cron (Rekommenderad)",
     "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "För att köra detta behöver du PHP POSIX-tillägget. Se {linkstart}PHP dokumentation{linkend} för mer detaljer.",
+    "Use system cron service to call the cron.php file every 5 minutes. Recommended for all instances." : "Använd systemets cron-tjänst för att anropa filen cron.php var 5:e minut. Rekommenderas för alla fall.",
+    "The cron.php needs to be executed by the system user \"{user}\"." : "cron.php måste köras av systemanvändaren \"{user}\".",
+    "Unable to update background job mode" : "Det gick inte att uppdatera bakgrundsjobbläget",
     "Profile" : "Profil",
+    "Enable or disable profile by default for new users." : "Aktivera eller inaktivera profil som standard för nya användare.",
     "Enable" : "Aktivera",
+    "Unable to update profile default setting" : "Det gick inte att uppdatera profilens standardinställning",
     "Server-side encryption" : "Serverkryptering",
     "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "Kryptering från servern möjliggör kryptering av filer som är uppladdade till servern. Detta innebär vissa begränsningar som prestandaförluster, så aktivera bara om det behövs.",
     "Enable server-side encryption" : "Aktivera kryptering på server.",
+    "Please read carefully before activating server-side encryption:" : "Läs noga innan du aktiverar kryptering på serversidan:",
     "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "När kryptering är aktiverat, så kommer alla filer som laddas upp till servern från den tidpunkt och framåt bli krypterad på servern. Det kommer bara vara möjligt att inaktivera kryptering vid ett senare tillfälle om krypteringsmodulen stödjer den funktionen och alla förvillkor (exempelvis använder återställningsnyckel) är mötta.",
     "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "Enbart kryptering garanterar inte säkerhet i systemet. Se dokumentationen för ytterligare information om hur krypteringsappen fungerar, och de supporterade användarfallen.",
     "Be aware that encryption always increases the file size." : "OBS! Observera att kryptering alltid ökar filstorleken",
@@ -215,15 +258,30 @@ OC.L10N.register(
     "This is the final warning: Do you really want to enable encryption?" : "Detta är en slutgiltig varning: Vill du verkligen aktivera kryptering?",
     "No encryption module loaded, please enable an encryption module in the app menu." : "Ingen krypteringsmodul inläst, aktivera krypteringsmodulen i applikationsmenyn.",
     "Select default encryption module:" : "Välj krypteringsmodul:",
+    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run {command}" : "Du måste migrera dina krypteringsnycklar från den gamla krypteringen (ownCloud <= 8.0) till den nya. Aktivera \"Standard krypteringsmodule\" och kör {command}",
+    "Unable to update server side encryption config" : "Kunde inte uppdatera serversidans krypteringskonfiguration",
+    "Rename group" : "Byt namn på grupp",
     "Remove group" : "Ta bort grupp",
     "You are about to remove the group {group}. The users will NOT be deleted." : "Du håller på att ta bort gruppen {group}. Användarna kommer INTE att raderas.",
     "Please confirm the group removal " : "Bekräfta borttagning av gruppen",
     "Current password" : "Nuvarande lösenord",
     "New password" : "Nytt lösenord",
     "Change password" : "Ändra lösenord",
+    "Your profile picture" : "Din profilbild",
+    "Upload profile picture" : "Ladda upp profilbild",
+    "Choose profile picture from files" : "Välj profilbild från filer",
+    "Remove profile picture" : "Ta bort profilbild",
     "png or jpg, max. 20 MB" : "png eller jpg, max 20 MB",
     "Picture provided by original account" : "Bild gjordes tillgänglig av orginalkonto",
     "Cancel" : "Avbryt",
+    "Set as profile picture" : "Ställ in som profilbild",
+    "Please note that it can take up to 24 hours for your profile picture to be updated everywhere." : "Observera att det kan ta upp till 24 timmar för din profilbild att uppdateras överallt.",
+    "Choose your profile picture" : "Välj din profilbild",
+    "Please select a valid png or jpg file" : "Välj en giltig png- eller jpg-fil",
+    "Error setting profile picture" : "Fel vid inställning av profilbild",
+    "Error cropping profile picture" : "Det gick inte att beskära profilbilden",
+    "Error saving profile picture" : "Det gick inte att spara profilbilden",
+    "Error removing profile picture" : "Det gick inte att ta bort profilbilden",
     "Your biography" : "Din biografi",
     "Details" : "Detaljer",
     "You are a member of the following groups:" : "Du är medlem i följande grupper:",
@@ -253,16 +311,25 @@ OC.L10N.register(
     "No language set" : "Inget språk angivet",
     "Locale" : "Plats",
     "Week starts on {firstDayOfWeek}" : "Veckan börjar med {firstDayOfWeek}",
+    "Unable to update locale" : "Det gick inte att uppdatera språk",
+    "No locale set" : "Inget språk angivet",
+    "Your location" : "Din plats",
     "Your organisation" : "Din organisation",
     "Your phone number" : "Ditt telefonnummer",
     "Edit your Profile visibility" : "Ändra synligheten för din profil",
     "Enable Profile" : "Aktivera profil",
     "Unable to update profile enabled state" : "Kunde inte uppdatera profilaktivering",
-    "{displayId}" : "{displayId}",
+    "The more restrictive setting of either visibility or scope is respected on your Profile. For example, if visibility is set to \"Show to everyone\" and scope is set to \"Private\", \"Private\" is respected." : "Den mer restriktiva inställningen av antingen synlighet eller omfattning respekteras på din profil. Till exempel, om synlighet är inställd på \"Visa för alla\" och omfattningen är inställd på \"Privat\", respekteras \"Privat\".",
     "Unable to update visibility of {displayId}" : "Kunde inte uppdatera synlighet för {displayId}",
     "Your role" : "Din roll",
     "Your Twitter handle" : "Ditt Twitterkonto",
     "Your website" : "Din webbsida",
+    "No {property} set" : "Ingen {property} inställd",
+    "Unable to update {property}" : "Det gick inte att uppdatera {property}",
+    "Change scope level of {property}, current scope is {scope}" : "Ändra omfattningsnivå för {property}, nuvarande omfattning är {scope}",
+    "Unable to update federation scope of the primary {property}" : "Det gick inte att uppdatera federationsomfånget för den primära {property}",
+    "Unable to update federation scope of additional {property}" : "Det gick inte att uppdatera federationens omfattning för ytterligare {property}",
+    "Add additional email" : "Lägg till ytterligare e-post",
     "Add" : "Lägg till",
     "You do not have permissions to see the details of this user" : "Du har inte behörighet att se detaljerna för den här användaren",
     "Add new password" : "Lägg till nytt lösenord",
@@ -315,11 +382,6 @@ OC.L10N.register(
     "The following devices are configured for your account:" : "Följande enheter är konfigurerade för ditt konto:",
     "Your browser does not support WebAuthn." : "Din webbläsare stödjer inte WebAuthn.",
     "Your apps" : "Dina appar",
-    "Active apps" : "Aktiva appar",
-    "Disabled apps" : "Inaktiverade appar",
-    "Updates" : "Uppdateringar",
-    "App bundles" : "App-paket",
-    "Featured apps" : "Utvalda appar",
     "{license}-licensed" : "{license}-licensierad",
     "Changelog" : "Ändringslogg",
     "by {author}\n{license}" : "av {author}\n{license}",
@@ -348,10 +410,17 @@ OC.L10N.register(
     "Phone number" : "Telefonnummer",
     "Role" : "Roll",
     "Twitter" : "Twitter",
+    "Fediverse (e.g. Mastodon)" : "Fediverse (t.ex. Mastodon)",
     "Website" : "Webbplats",
     "Profile visibility" : "Profilsynlighet",
     "Not available as this property is required for core functionality including file sharing and calendar invitations" : "Inte tillgänglig då denna inställning krävs för essentiell funktionalitet såsom fildelning och kalenderinbjudningar",
+    "Not available as federation has been disabled for your account, contact your system administrator if you have any questions" : "Ej tillgängligt eftersom federation har inaktiverats för ditt konto, kontakta din systemadministratör om du har några frågor",
     "Not available as publishing user specific data to the lookup server is not allowed, contact your system administrator if you have any questions" : "Inte tillgänglig då publicering av användarspecifik data till lookup-servern inte är tillåten, kontakta din systemadministratör ifall du har frågor",
+    "Active apps" : "Aktiva appar",
+    "Disabled apps" : "Inaktiverade appar",
+    "Updates" : "Uppdateringar",
+    "App bundles" : "App-paket",
+    "Featured apps" : "Utvalda appar",
     "Show to everyone" : "Visa för alla",
     "Show to logged in users only" : "Visa endast för inloggade användare",
     "Hide" : "Dölj",
@@ -360,30 +429,29 @@ OC.L10N.register(
     "The app will be downloaded from the App Store" : "Appen kommer hämtas från appbutiken",
     "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Den här appen är inte markerad som kompatibel med din Nextcloud-version. Om du fortsätter kan du fortfarande installera appen. Observera att appen kanske inte fungerar som förväntat.",
     "Never" : "Aldrig",
+    "An error occurred during the request. Unable to proceed." : "Ett fel uppstod under begäran. Det gick inte att fortsätta.",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Appen har aktiverats men måste uppdateras. Du kommer att omdirigeras till uppdateringssidan om 5 sekunder.",
     "Error: This app cannot be enabled because it makes the server unstable" : "Fel: Denna appen kan inte aktiveras eftersom den gör servern instabil",
-    "Administrator documentation" : "Administratörsdokumentation",
     "Documentation" : "Dokumentation",
     "Forum" : "Forum",
     "Login" : "Logga in",
-    "Plain" : "Enkel",
-    "NT LAN Manager" : "NT LAN Manager",
     "SSL/TLS" : "SSL/TLS",
-    "STARTTLS" : "STARTTLS",
     "Open documentation" : "Öppna dokumentation",
     "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Det är viktigt att konfigurera den här servern för att kunna skicka e-post, till exempel för återställning av lösenord och aviseringar.",
     "Send mode" : "Sändningsläge",
     "Encryption" : "Kryptering",
     "Sendmail mode" : "Sendmail-läge",
     "From address" : "Från adress",
-    "Authentication method" : "Autentiseringsmetod",
-    "Authentication required" : "Autentisering krävs",
     "Server address" : "Serveradress",
     "Port" : "Port",
+    "Authentication method" : "Autentiseringsmetod",
+    "Only applies when authentication is required" : "Gäller endast när autentisering krävs",
+    "Authentication required" : "Autentisering krävs",
     "Credentials" : "Inloggningsuppgifter",
     "SMTP Username" : "SMTP-användarnamn",
     "SMTP Password" : "SMTP-lösenord",
     "Save" : "Spara",
+    "Test and verify email settings" : "Testa och verifiera e-postinställningar",
     "Send email" : "Skicka e-post",
     "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Det är viktigt för säkerhet och prestanda av din instans att allt är korrekt konfigurerat. För att hjälpa dig med det gör vi några automatiska kontroller. Se den länkade dokumentationen för mer information.",
     "All checks passed." : "Alla kontroller lyckades!",
@@ -405,6 +473,7 @@ OC.L10N.register(
     "Allow public uploads" : "Tillåt offentlig uppladdning",
     "Always ask for a password" : "Fråga alltid efter lösenord",
     "Enforce password protection" : "Tillämpa lösenordskydd",
+    "Exclude groups from password requirements:" : "Exkludera grupper från lösenordskrav: ",
     "Set default expiration date" : "Ställ in standardutgångsdatum",
     "Exclude groups from creating link shares:" : "Exkludera grupper från att skapa länkdelningar:",
     "Allow resharing" : "Tillåt vidaredelning",
@@ -416,6 +485,7 @@ OC.L10N.register(
     "Allow username autocompletion to users within the same groups" : "Tillåt autokomplettering av användarnamn till användare inom samma grupper",
     "Allow username autocompletion to users based on phone number integration" : "Tillåt autokomplettering av användarnamn till användare baserad på telefonnummerintegration",
     "If autocompletion \"same group\" and \"phone number integration\" are enabled a match in either is enough to show the user." : "Om komplettering för \"samma grupp\" och \"telefonnummerintegration\" är aktiverade räcker det med en matchning i en av dem för att visa användaren.",
+    "Allow autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)" : "Tillåt autokomplettering när du anger hela namnet eller e-postadressen (ignorera saknad telefonboksmatchning och att vara i samma grupp)",
     "Show disclaimer text on the public link upload page (only shown when the file list is hidden)" : "Visa friskrivningstext på offentliga uppladdningssidan (visas endast när fil-listan är gömd)",
     "This text will be shown on the public link upload page when the file list is hidden." : "Denna text kommer att visa på den offentliga uppladdnings-sidan när fil-listan är gömd.",
     "Default share permissions" : "Standardrättigheter för delning",
@@ -429,24 +499,35 @@ OC.L10N.register(
     "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Denna community-release av Nextcloud stöds inte och direktnotifikationer är inte tillgängliga.",
     "Use a second factor besides your password to increase security for your account." : "Använd en andra faktor förutom ditt lösenord för att öka säkerheten för ditt konto.",
     "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Om du använder tredje-parts applikationer för att ansluta till Nextcloud vänligen skapa och konfigurera ett applösenord för varje innan två-faktor autentisering aktiveras.",
-    "Migration in progress. Please wait until the migration is finished" : "Migration pågår. Vänta tills migrationen är klar",
-    "Migration started …" : "Migrering påbörjad ...",
     "An error occurred while changing your language. Please reload the page and try again." : "Ett fel inträffade när ditt språk ändrades. Vänligen uppdatera sidan och försök igen.",
     "An error occurred while changing your locale. Please reload the page and try again." : "Ett fel inträffade när din språk ändrades. Vänligen uppdatera sidan och försök igen.",
     "Select a profile picture" : "Välj en profilbild",
     "Week starts on {fdow}" : "Veckan börjar med {fdow}",
+    "You created app password \"{token}\"" : "Du skapade applösenord \"{token}\"",
+    "An administrator created app password \"{token}\"" : "En administratör skapade applösenord \"{token}\"",
     "Couldn't remove app." : "Kunde inte ta bort applikationen.",
     "Couldn't update app." : "Kunde inte uppdatera appen.",
     "Backend doesn't support password change, but the user's encryption key was updated." : "Backend stödjer inte att lösenord ändras men användarens krypteringsnyckel uppdaterades.",
     "Could not determine if TLS version of cURL is outdated or not because an error happened during the HTTPS request against https://nextcloud.com. Please check the nextcloud log file for more details." : "Kunde inte bestämma om TLS-versionen av cURL är för gammal eller inte för ett fel uppstod under HTTPS-förfrågan mot https://nextcloud.com. Vänligen kontrollera nextcloud loggfilen för fler detaljer.",
-    "You need to set your user email before being able to send test emails." : "Du behöver ställa in din användares e-postadress före du kan skicka test e-post.",
-    "Revoking this token might prevent the wiping of your device if it hasn't started the wipe yet." : "Återkallning kan förhindra att enheten rensas om inte rensningen redan har startat.",
-    "Set as primary mail" : "Sätt som primär e-postadress",
-    "Change privacy level of email" : "Ändra hemlighetsnivå för e-post",
-    "All languages" : "Alla språk",
-    "Everyone" : "Alla",
+    "The maximum number of OPcache keys is nearly exceeded. To assure that all scripts can be hold in cache, it is recommended to apply <code>opcache.max_accelerated_files</code> to your PHP configuration with a value higher than <code>%s</code>." : "Det maximala antalet OPcache-nycklar har nästan överskridits. För att säkerställa att alla skript kan hållas i cache, rekommenderas det att tillämpa <code>opcache.max_accelerated_files</code> i din PHP-konfiguration med ett värde högre än <code>%s</code>.",
+    "Admin privileges" : "Adminprivilegier",
+    "Unable to update biography" : "Kunde inte uppdatera biografi",
+    "Unable to update full name" : "Kunde inte uppdatera fullständigt namn",
+    "No full name set" : "Inget fullständigt namn angivet",
+    "Unable to update headline" : "Kunde inte uppdatera rubrik",
+    "Unable to update organisation" : "Kunde inte uppdatera organisation",
+    "Unable to update role" : "Kunde inte uppdatera roll",
+    "Change scope level of {accountProperty}" : "Ändra omfattningsnivå för {accountProperty}",
+    "Unable to update federation scope of the primary {accountProperty}" : "Det gick inte att uppdatera federationsomfånget för primära {accountProperty}",
+    "Unable to update federation scope of additional {accountProperty}" : "Det gick inte att uppdatera federationens omfattning för ytterligare {accountProperty}",
+    "Migration in progress. Please wait until the migration is finished" : "Migration pågår. Vänta tills migrationen är klar",
+    "Migration started …" : "Migrering påbörjad ...",
+    "Address" : "Ort/Stad",
+    "Avatar" : "Avatar",
     "An error occured during the request. Unable to proceed." : "Ett fel uppstod under förfrågan. Kan inte fortsätta.",
-    "Test email settings" : "Testa e-postinställningar",
+    "Plain" : "Enkel",
+    "NT LAN Manager" : "NT LAN Manager",
+    "STARTTLS" : "STARTTLS",
     "Please read carefully before activating server-side encryption: " : "Läs noga innan du aktiverar kryptering på serversidan: ",
     "Enable encryption" : "Aktivera kryptering",
     "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Du behöver migrera dina krypteringsnycklar från den gamla krypteringen (owncloud <= 8.0) till den nya. Aktivera \"Standard krypteringsmodul\" och kör 'occ encryption:migrate'.",
@@ -457,36 +538,25 @@ OC.L10N.register(
     "Some jobs didn’t execute since %s. Please consider switching to system cron." : "Vissa jobb utfördes inte sedan %s. Överväg att byta till system cron.",
     "Last job ran %s." : "Senaste jobbet kördes %s.",
     "Background job didn’t run yet!" : "Bakgrundsjobb har inte kört ännu!",
+    "For the server to work properly, it's important to configure background jobs correctly. \"Cron\" is the recommended setting. Please see the documentation for more information." : "För att servern ska fungera korrekt är det viktigt att konfigurera bakgrundsjobb korrekt. \"Cron\" är den rekommenderade inställningen. Se dokumentationen för mer information.",
     "Pick background job setting" : "Välj inställning för bakgrundsjobb",
     "Recommended" : "Rekomenderad",
     "The cron.php needs to be executed by the system user \"%s\"." : "Cron.php behöver exekveras av systemanvändaren \"%s\".",
-    "days" : "dagar",
-    "Allow username autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)" : "Tillåt komplettering av användarnamn vid ifyllning av fullständigt namn eller e-postadress (bortser från saknande matchning i telefonboken eller grupptillhörighet i samma grupp)",
     "Change privacy level of profile picture" : "Ändra hemlighetsnivå för profilbild",
     "Upload new" : "Ladda upp ny",
     "Select from Files" : "Välj från Filer",
     "Remove image" : "Ta bort bild",
+    "Please note that it can take up to 24 hours for the avatar to get updated everywhere." : "Observera att det kan ta upp till 24 timmar för avataren att uppdateras överallt.",
     "Choose as profile picture" : "Välj som profilbild",
     "You are using <strong>%s</strong>" : "Du använder <strong>%s</strong>",
     "You are using <strong>%1$s</strong> of <strong>%2$s</strong> (<strong>%3$s %%</strong>)" : "Du använder <strong>%1$s</strong> av <strong>%2$s</strong> (<strong>%3$s %%</strong>)",
-    "Change privacy level of full name" : "Ändra hemlighetsnivå för helt namn",
-    "No display name set" : "Inget visningsnamn angivet",
     "Change privacy level of phone number" : "Ända hemlighetsnivå för telefonnummer",
-    "Address" : "Ort/Stad",
     "Change privacy level of address" : "Ända hemlighetsnivå för adress",
     "Your postal address" : "Ort/Stad",
     "Change privacy level of website" : "Ända hemlighetsnivå för hemsida",
     "It can take up to 24 hours before the account is displayed as verified." : "Det kan ta upp till 24 timmar innan kontot visas som verifierat.",
     "Link https://…" : "Länk https://...",
     "Change privacy level of Twitter profile" : "Ända hemlighetsnivå för Twitterprofil",
-    "Twitter handle @…" : "Twitter handle @…",
-    "Admin privileges" : "Adminprivilegier",
-    "Unable to update biography" : "Kunde inte uppdatera biografi",
-    "Unable to update full name" : "Kunde inte uppdatera fullständigt namn",
-    "No full name set" : "Inget fullständigt namn angivet",
-    "Unable to update headline" : "Kunde inte uppdatera rubrik",
-    "Unable to update organisation" : "Kunde inte uppdatera organisation",
-    "Unable to update role" : "Kunde inte uppdatera roll",
-    "Avatar" : "Avatar"
+    "Twitter handle @…" : "Twitter handle @…"
 },
 "nplurals=2; plural=(n != 1);");
