@@ -45,7 +45,6 @@ OC.L10N.register(
     "Repair info:" : "Información de reparación:",
     "Repair warning:" : "Advertencia de reparación:",
     "Repair error:" : "Error de reparación: ",
-    "Please use the command line updater because automatic updating is disabled in the config.php." : "Por favor usa el actualizador de línea de comandos ya que el actualizador automático se encuentra deshabilitado en config.php.",
     "Turned on maintenance mode" : "Modo mantenimiento activado",
     "Turned off maintenance mode" : "Modo mantenimiento desactivado",
     "Maintenance mode is kept active" : "El modo mantenimiento sigue activo",
@@ -76,6 +75,7 @@ OC.L10N.register(
     "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Tu PHP no cuenta con soporte FreeType, lo que resulta en fallas en la imagen de perfil y la interface de configuraciones. ",
     "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "Actualmente estás usando SQLite como el backend de base de datos. Para instalaciones más grandes te recomendamos cambiar a un backend de base de datos diferente.",
     "This is particularly recommended when using the desktop client for file synchronisation." : "Esto es particularmente recomendado cuando se usa el cliente de escritorio para sincronización de archivos. ",
+    "This instance uses an S3 based object store as primary storage. The uploaded files are stored temporarily on the server and thus it is recommended to have 50 GB of free space available in the temp directory of PHP. Check the logs for full details about the path and the available space. To improve this please change the temporary directory in the php.ini or make more space available in that path." : "Esta instancia usa un almacenamiento de objetos basado en S3 como almacenamiento primario. Los archivos subidos se almacena temporalmente en el servidor y por eso se recomienda tener 50 GB de espacio libre en el directorio temporal de PHP. Comprueba los registros para detalles completos sobre la ruta y el espacio disponible. Para mejora esto, por favor, cambia el directorio temporal en el php.ini o aumenta el espacio disponible en esa ruta.",
     "Error occurred while checking server setup" : "Se presentó un error al verificar la configuración del servidor",
     "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "El encabezado HTTP \"{header}\" está establecido a \"{expected}\". Esto representa un riesgo potencial de seguridad o privacidad, y que se recomienda ajustar esta configuración. ",
     "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "El encabezado HTTP \"{header}\" no está establecido a \"{expected}\". Puede que lgunas características no funcionen correctamente, y se recomienda ajustar esta confirguración. ",
@@ -102,12 +102,14 @@ OC.L10N.register(
     "Please contact your administrator." : "Por favor contacta al administrador.",
     "An internal error occurred." : "Se presentó un error interno.",
     "Please try again or contact your administrator." : "Por favor vuelve a intentarlo o contacta a tu adminsitrador. ",
+    "Account name or email" : "Nombre de cuenta o correo electrónico",
     "Password" : "Contraseña",
+    "Log in to {productName}" : "Iniciar sesión en {productName}",
     "Wrong username or password." : "Usuario o contraseña equivocado. ",
     "User disabled" : "Usuario deshabilitado",
     "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Hemos detectado múltiples intentos de inicio de sesión desde tu IP. Por lo tanto tu siguiente incio de sesión se retrasará hasta 30 segundos. ",
     "Username or email" : "Usuario o correo electrónico",
-    "Your account is not setup for passwordless login." : "Tu cuenta no está configurada para iniciar de sesión sin contraseña",
+    "Your account is not setup for passwordless login." : "Tu cuenta no está configurada para iniciar sesión sin contraseña",
     "Browser not supported" : "Navegador no compatible",
     "Passwordless authentication is not supported in your browser." : "La autenticación sin contraseña no está soportada en tu navegador.",
     "Your connection is not secure" : "Tu conexión no es segura",
@@ -129,9 +131,12 @@ OC.L10N.register(
     "Skip" : "Saltar",
     "Install recommended apps" : "Instalar las aplicaciones recomendadas",
     "Forgot password?" : "¿Olvidaste tu contraseña?",
+    "Log in with a device" : "Iniciar sesión con dispositivo",
     "Back" : "Atrás",
+    "Login form is disabled." : "La página de inicio de sesión está deshabilitada.",
     "Reset search" : "Reestablecer búsqueda",
     "Search" : "Buscar",
+    "Settings menu" : "Menú de Configuraciones",
     "Settings" : "Configuraciones ",
     "Could not load your contacts" : "No fue posible cargar tus contactos",
     "Search contacts …" : "Buscar contactos ...",
@@ -169,7 +174,10 @@ OC.L10N.register(
     "(all selected)" : "(todos seleccionados)",
     "({count} selected)" : "({count} seleccionados)",
     "Error loading file exists template" : "Se presentó un error al cargar la plantilla de existe archivo ",
+    "Show list view" : "Mostrar vista de lista",
+    "Show grid view" : "Mostrar vista de cuadrícula",
     "Pending" : "Pendiente",
+    "Home" : "Inicio",
     "Copy to {folder}" : "Copiar a {folder}",
     "Move to {folder}" : "Mover a {folder}",
     "Authentication required" : "Se requiere autenticación",
@@ -179,6 +187,7 @@ OC.L10N.register(
     "seconds ago" : "hace segundos",
     "Connection to server lost" : "Se ha perdido la conexión con el servidor",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Se presentó un error al cargar la página, recargando en %n segundo","Se presentó un error al cargar la página, recargando en %n segundos","Se presentó un error al cargar la página, recargando en %n segundos"],
+    "Show details" : "Mostrar detalles",
     "Hide details" : "Ocultar detalles",
     "Very weak password" : "Contraseña muy débil",
     "Weak password" : "Contraseña débil",
@@ -238,18 +247,20 @@ OC.L10N.register(
     "Need help?" : "¿Necesitas ayuda?",
     "See the documentation" : "Ver la documentación",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Esta aplicación requiere de JavaScript para su correcta operación. Por favor {linkstart}habilita JavaScript{linkend} y vuelve a cargar la página. ",
-    "Contacts" : "Contactos",
-    "Contacts menu" : "Menú de Contactos",
     "Confirm your password" : "Confirma tu contraseña",
     "Connect to your account" : "Conectate a tu cuenta",
+    "Please log in before granting %1$s access to your %2$s account." : "Por favor, inicia sesión antes de conceder a %1$s acceso a tu cuenta %2$s.",
     "App token" : "Ficha de la aplicación",
     "Grant access" : "Conceder acceso",
     "Alternative log in using app token" : "Inicio de sesión alternativo usando una ficha de aplicación",
     "Account access" : "Acceo de cuenta",
+    "Currently logged in as %1$s (%2$s)." : "Actualmente está conectado como %1$s (%2$s).",
     "This share is password-protected" : "Este elemento compartido está protegido con contraseña",
     "Go to %s" : "Ir a %s",
     "Two-factor authentication" : "Autenticación de dos-factores",
+    "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "La autenticación en dos pasos es obligatoria pero no se ha configurado en su cuenta. Use uno de sus códigos de respaldo para iniciar sesión o comuníquese con su administrador para obtener ayuda.",
     "Use backup code" : "Usar código de respaldo",
+    "Cancel login" : "Cancelar inicio de sesión",
     "Error while validating your second factor" : "Se presentó un error al validar tu segundo factor",
     "Access through untrusted domain" : "Accesa a través de un dominio no de confianza",
     "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Por favor contacta a tu adminsitrador. Si tu eres un administrador, edita la propiedad \"trusted_domains\" en el archivo config/config.php como en el ejemplo config.sample.php.",
@@ -262,22 +273,20 @@ OC.L10N.register(
     "Detailed logs" : "Bitácoras detalladas",
     "Update needed" : "Se requiere de una actualización",
     "Please use the command line updater because you have a big instance with more than 50 users." : "Favor de usar el actualizador desde la línea de comandos ya que tu instancia cuenta con más de 50 usuarios.",
+    "Please use the command line updater because automatic updating is disabled in the config.php." : "Por favor usa el actualizador de línea de comandos ya que el actualizador automático se encuentra deshabilitado en config.php.",
     "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Para más ayuda, por favor consulta la <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentación</a>.",
     "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Estoy conciente de que si continúo haciendo la actualización vía web, la interfaz de usuario corre el riesgo de que el tiempo de la solicitud expire y cause pérdida de datos, pero cuento con un respaldo y sé como restaurar mi instancia en caso de una falla. ",
     "Upgrade via web on my own risk" : "Actualizar vía Web bajo mi propio riesgo",
     "This %s instance is currently in maintenance mode, which may take a while." : "Esta instancia %s se encuentra actualmente en modo mantenimiento, que podría tomar algo de tiempo. ",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Contacta a tu administrador del sistema si este mensaje persiste o se presentó de manera inesperada.",
-    "Enter your subscription key to increase the user limit. For more information about Nextcloud Enterprise see our website." : "Introduzca su clave de suscripción para aumentar el límite de usuarios. Para obtener más información sobre Nextcloud Enterprise, visite nuestro sitio web.",
+    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "El lanzamiento de esta versión para la comunidad de Nextcloud no cuenta con soporte y las notificaciones instantáneas no están disponibles.",
     "[%d / %d]: Checking table %s" : "[%d / %d]: Verificando tabla %s",
-    "This server has no working Internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the Internet to enjoy all features." : "El servidor no cuenta con una conexión a Internet: No se pudieron alcanzar múltiples endpoints. Esto significa que algunas características como montar almacenamiento externo, notificaciones de actualizaciones o instalación de aplicaciones de 3ros no funcionarán correctamente. Acceder archivos de forma remota y el envío de de notificaciones por correo electrónico puede que no funcionen tampoco. Establece una conexión desde este servidor a Internet para aprovechar todas las funcionalidades.",
-    "Your data directory and files are probably accessible from the Internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Probablemente tu directorio de datos y archivos sean accesibles desde Internet. El archivo .htaccess no está funcionando. Se recomienda ampliamente que configures tu servidor web para que el directorio de datos no sea accesible, o bien, que muevas el directorio de datos fuera del directorio raíz del servidor web.",
     "restricted" : "restringido",
     "invisible" : "invisible",
     "File not found" : "Archivo no encontrado",
     "More" : "Más",
     "More apps menu" : "Menú de más aplicaciones",
-    "Settings menu" : "Menú de Configuraciones",
-    "The password is wrong. Try again." : "La contraseña está equivoada. Por favor vuelve a intentarlo. ",
-    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "El lanzamiento de esta versión para la comunidad de Nextcloud no cuenta con soporte y las notificaciones instantáneas no están disponibles."
+    "Contacts" : "Contactos",
+    "Contacts menu" : "Menú de Contactos"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
