@@ -25,11 +25,15 @@ OC.L10N.register(
     "State token does not match" : "Tillstånds-token matchar inte",
     "Invalid app password" : "Felaktigt app-lösenord",
     "Could not complete login" : "Kunde inte slutföra inloggningen",
+    "State token missing" : "Statustoken saknas",
     "Your login token is invalid or has expired" : "Din inloggnings-token är ogiltigt eller har gått ut",
+    "This community release of Nextcloud is unsupported and push notifications are limited." : "Denna community-release av Nextcloud stöds inte och pushnotifikationer är begränsade.",
     "Login" : "Logga in",
+    "Please try again" : "Var vänlig och försök igen",
     "Password reset is disabled" : "Lösenordsåterställning är avaktiverat",
     "Could not reset password because the token is expired" : "Kunde inte återställa lösenord eftersom token har utgått",
     "Could not reset password because the token is invalid" : "Kunde inte återställa lösenord eftersom token är ogiltigt",
+    "Password is too long. Maximum allowed length is 469 characters." : "Lösenordet är för långt. Högsta tillåtna längd är 469 tecken.",
     "%s password reset" : "%s återställ lösenord",
     "Password reset" : "Lösenordsåterställning",
     "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Klicka på knappen för att återställa ditt lösenord.  Om du inte har begärt att återställa ditt lösenord så kan du ignorera detta epost, inget kommer då att ske.",
@@ -39,6 +43,7 @@ OC.L10N.register(
     "Some of your link shares have been removed" : "Några av dina delade länkar har tagits bort",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "På grund av ett säkerhetsfel var vi tvungna att ta bort några av dina delade länkar. Se länken för mer information.",
     "The user limit of this instance is reached." : "Maximala användarantalet för denna instansen har uppnåts",
+    "Enter your subscription key in the support app in order to increase the user limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Ange din prenumerationsnyckel i supportappen för att öka användargränsen. Detta ger dig också alla ytterligare fördelar som Nextcloud Enterprise erbjuder och rekommenderas starkt för användning i företag.",
     "Learn more ↗" : "Läs mer ↗",
     "Preparing update" : "Förbereder uppdatering",
     "[%d / %d]: %s" : "[%d / %d]: %s",
@@ -46,7 +51,7 @@ OC.L10N.register(
     "Repair info:" : "Reparationsinfo:",
     "Repair warning:" : "Reperationsvarning:",
     "Repair error:" : "Reperationsfel:",
-    "Please use the command line updater because automatic updating is disabled in the config.php." : "Uppdatera via kommandotolken då automatisk uppdatering är inaktiverat i config.php.",
+    "Please use the command line updater because updating via the browser is disabled in your config.php." : "Var vänlig och uppdatera via kommandotolken då uppdatering via webbläsaren är inaktiverat i config.php",
     "Turned on maintenance mode" : "Aktiverade underhållsläge",
     "Turned off maintenance mode" : "Inaktivera underhållsläge",
     "Maintenance mode is kept active" : "Underhållsläget förblir aktiverat",
@@ -73,20 +78,26 @@ OC.L10N.register(
     "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Databasen körs inte med transaktionsisoleringsnivån \"READ COMMITTED\". Det kan orsaka problem när flera aktiviteter körs parallellt.",
     "The PHP module \"fileinfo\" is missing. It is strongly recommended to enable this module to get the best results with MIME type detection." : "PHP-modulen \"fileinfo\" saknas. Det rekommenderas starkt att göra det möjligt för den här modulen att få bästa resultat med MIME-typdetektering.",
     "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems. See the {linkstart}documentation ↗{linkend} for more information." : "Transaktionsfillåsning är inaktiverad, detta kan leda till problem med. Aktivera \"filelocking.enabled\" i config.php för att undvika dessa problem. Se {linkstart}dokumentationen ↗{linkend} för mer information.",
+    "Please make sure to set the \"overwrite.cli.url\" option in your config.php file to the URL that your users mainly use to access this Nextcloud. Suggestion: \"{suggestedOverwriteCliURL}\". Otherwise there might be problems with the URL generation via cron. (It is possible though that the suggested URL is not the URL that your users mainly use to access this Nextcloud. Best is to double check this in any case.)" : "Se till att ställa in konfigurationsalternativet \"overwrite.cli.url\" i din config.php-fil till den URL som dina användare huvudsakligen använder för att komma åt detta Nextcloud. Förslag: \"{suggestedOverwriteCliURL}\". Annars kan det uppstå problem med URL-genereringen via cron. (Det är dock möjligt att den föreslagna URL:en inte är den URL som dina användare huvudsakligen använder för att komma åt detta Nextcloud. Bäst är att dubbelkolla detta i alla fall.)",
     "Your installation has no default phone region set. This is required to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective {linkstart}ISO 3166-1 code ↗{linkend} of the region to your config file." : "Din installation har ingen standardtelefonregion inställd. Detta krävs för att validera telefonnummer i profilinställningarna utan landskod. För att tillåta nummer utan landskod, lägg till \"default_phone_region\" med respektive {linkstart}ISO 3166-1-kod ↗{linkend} för regionen i din konfigurationsfil.",
     "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "Det var inte möjligt att utföra cron-jobbet via CLI. Följande tekniska fel har uppstått:",
     "Last background job execution ran {relativeTime}. Something seems wrong. {linkstart}Check the background job settings ↗{linkend}." : "Senaste bakgrundsjobbet kördes {relativeTime}. Något verkar fel. {linkstart}Kontrollera inställningarna för bakgrundsjobb ↗{linkend}.",
+    "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications are limited to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at {linkstart}https://nextcloud.com/enterprise{linkend}." : "Detta är Nextclouds communitybygge utan support från Nextcloud GmbH. Med tanke på storleken på denna instans kan prestanda, tillförlitlighet och skalbarhet inte garanteras. Push-meddelanden har begränsats för att undvika överbelastning av vår gratistjänst. Lär dig mer om fördelarna med Nextcloud Enterprise på {linkstart}https://nextcloud.com/enterprise{linkend}.",
     "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features." : "Den här servern har ingen fungerande internetanslutning: Flera slutpunkter kunde inte nås. Det betyder att vissa av funktionerna som montering av extern lagring, aviseringar om uppdateringar eller installation av tredjepartsappar inte kommer att fungera. Att komma åt filer på distans och skicka e-postmeddelanden kanske inte heller fungerar. Upprätta en anslutning från denna server till internet för att kunna nyttja alla funktioner.",
     "No memory cache has been configured. To enhance performance, please configure a memcache, if available. Further information can be found in the {linkstart}documentation ↗{linkend}." : "Inget minnescache har konfigurerats. För att förbättra prestandan, vänligen konfigurera en memcache, om tillgänglig. Mer information finns i {linkstart}dokumentationen ↗{linkend}.",
     "No suitable source for randomness found by PHP which is highly discouraged for security reasons. Further information can be found in the {linkstart}documentation ↗{linkend}." : "Ingen lämplig källa för slumpmässighet hittas av PHP, Detta avråder vi från starkt på grund av säkerhetsskäl. Mer information finns i {linkstart}dokumentationen ↗{linkend}.",
     "You are currently running PHP {version}. Upgrade your PHP version to take advantage of {linkstart}performance and security updates provided by the PHP Group ↗{linkend} as soon as your distribution supports it." : "Du kör för nuvarande PHP {version}. Uppgradera din PHP version för att dra nytta av {linkstart}prestanda och säkerhetsuppdateringar tillhandahållna av PHP Group ↗{linkend} så snart din servermiljö stödjer det.",
-    "Nextcloud 23 is the last release supporting PHP 7.3. Nextcloud 24 requires at least PHP 7.4." : "Nextcloud 23 är den sista versionen som stödjer PHP 7.3. Nextcloud 24 kräver minst PHP 7.4.",
     "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud. Further information can be found in the {linkstart}documentation ↗{linkend}." : "Konfigurationen av den omvända proxyhuvudet är felaktig, eller så använder du Nextcloud från en betrodd proxy. Om inte, är detta ett säkerhetsproblem och kan tillåta en angripare att förfalska sin IP-adress som synlig för Nextcloud. Mer information finns i {linkstart}dokumentationen ↗{linkend}.",
+    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in the {linkstart1}documentation ↗{linkend}. ({linkstart2}List of invalid files…{linkend} / {linkstart3}Rescan…{linkend})" : "Några filer har inte klarat integritetskontrollen. Vidare information om hur man löser detta problem kan hittas i {linkstart1}dokumentationen↗{linkend}. ({linkstart2}Lista med de ogiltiga filerna…{linkend} / {linkstart3}Scanna igen…{linkend})",
+    "The PHP OPcache module is not properly configured. See the {linkstart}documentation ↗{linkend} for more information." : "PHP OPcache modulen är felaktigt inställd. Se {linkstart}dokumentationen ↗{linkend} för mer information",
     "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "PHP-funktionen \"set_time_limit\" är inte tillgänglig. Detta kan leda till att skript stoppas i mitten av utförandet och bryter din installation. Aktivering av denna funktion rekommenderas starkt.",
     "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Din PHP har inte FreeType-stöd, vilket resulterar i brott i profilbilder och inställningsgränssnittet.",
     "Missing index \"{indexName}\" in table \"{tableName}\"." : "Saknar index \"{indexName}\" i tabellen \"{tableName}\".",
     "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "Databasen saknar några index. Dessa adderas inte automatsikt då indexering av stora tabeller kan ta tid. Med kommandot  \"occ db:add-missing-indices\" kan de saknade indices läggas till manuellt utan att instansen behöver stoppas. Indexerade tabeller ger oftast mycket snabbare svar.",
+    "Missing primary key on table \"{tableName}\"." : "Saknar primärnyckel i tabellen \"{tableName}\".",
+    "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "Databasen saknar några primärnycklar. Eftersom att lägga till sådana i stora tabeller kan ta en del tid, har det inte gjorts automatiskt. Genom att köra kommandot \"occ db:add-missing-primary-keys\" läggs de saknade primärnycklarna till utan att instansen behöver stoppas.",
     "Missing optional column \"{columnName}\" in table \"{tableName}\"." : "Saknar den valfria kolumnen \"{columnName}\" i tabell \"{tableName}\".",
+    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "Databasen saknar några valfria kolumner. Eftersom att lägga till sådana i stora tabeller kan ta en del tid, har det inte gjorts automatiskt. Genom att köra kommandot \"occ db:add-missing-columns\" läggs de saknade kolumnerna till utan att instansen behöver stoppas. Att lägga till de valfria kolumnerna kan förbättra svarstid eller användbarhet.",
     "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them." : "Instansen saknar några rekommenderade PHP-moduler. För förbättrad prestanda och kompatibilitet är det starkt rekommenderat att installera dem.",
     "Module php-imagick in this instance has no SVG support. For better compatibility it is recommended to install it." : "Modulen php-image har i det här fallet inget SVG-stöd. För bättre kompatibilitet rekommenderas det att installera det.",
     "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "SQLite används som databas. För större installationer så rekommenderar vi ett byte till en annan databasbackend.",
@@ -95,6 +106,7 @@ OC.L10N.register(
     "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:" : "Vissa appkataloger ägs av en annan användare än den som äger webbservern. Detta kan vara fallet om appar har installerats manuellt. Kontrollera behörigheterna för följande appkataloger:",
     "The temporary directory of this instance points to an either non-existing or non-writable directory." : "Den tillfälliga katalogen för denna instans pekar på en icke-existerande eller icke-skrivbar katalog.",
     "Error occurred while checking server setup" : "Ett fel inträffade när en kontroll av serverns konfiguration utfördes",
+    "For more details see the {linkstart}documentation ↗{linkend}." : "För mer detaljer se {linkstart}dokumentationen ↗{linkend}.",
     "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "HTTP-rubriken \"{header}\" är inte inställd till \"{expected}\". Detta är en potentiell säkerhets- eller sekretessrisk, eftersom det rekommenderas att justera denna inställning i enlighet med detta.",
     "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "HTTP-rubriken \"{header}\" är inte inställd till \"{expected}\". Vissa funktioner kanske inte fungerar korrekt, eftersom det rekommenderas att justera den här inställningen i enlighet med detta.",
     "unknown text" : "okänd text",
@@ -122,9 +134,9 @@ OC.L10N.register(
     "Please contact your administrator." : "Kontakta din administratör.",
     "An internal error occurred." : "Ett internt fel uppstod.",
     "Please try again or contact your administrator." : "Försök igen eller kontakta din administratör.",
-    "Log in to {productName}" : "Logga in på {productName}",
     "Account name or email" : "Användarnamn eller e-post",
     "Password" : "Lösenord",
+    "Log in to {productName}" : "Logga in på {productName}",
     "Wrong username or password." : "Felaktigt användarnamn eller lösenord",
     "User disabled" : "Användare inaktiverad",
     "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Vi har upptäckt flera felaktiga inloggningsförsök från din IP-adress. Ditt nästa inloggningsförsök kommer därför att fördröjas med upp till 30 sekunder.",
@@ -157,6 +169,7 @@ OC.L10N.register(
     "Keep your colleagues and friends in one place without leaking their private info." : "Håll dina kollegor och vänner på ett ställe utan att läcka deras privata info.",
     "Simple email app nicely integrated with Files, Contacts and Calendar." : "Enkel e-post app integrerad med filer, kontakter och kalender.",
     "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Chatt, videosamtal, skärmdelning, onlinemöten och webbkonferenser – i din webbläsare och med mobilappar.",
+    "Search contacts" : "Sök kontakter",
     "Forgot password?" : "Glömt lösenordet?",
     "Log in with a device" : "Logga in med en enhet",
     "Back" : "Tillbaka",
@@ -166,16 +179,16 @@ OC.L10N.register(
     "You have not added any info yet" : "Du har inte angivit någon information ännu",
     "{user} has not added any info yet" : "{user} har inte angivit någon information ännu",
     "Error opening the user status modal, try hard refreshing the page" : "Kunde inte öppna användarstatus-rutan, försök att ladda om sidan",
-    "Search starts once you start typing" : "Sökningen startar när du börjar skriva",
+    "Search starts once you start typing and results may be reached with the arrow keys" : "Sökningen startar när du börjar skriva och resultat kan nås med piltangenterna",
     "Reset search" : "Återställ sökning",
     "Start search" : "Starta sökning",
     "Search for {name} only" : "Sök efter endast {name}",
-    "No results for {query}" : "Inga resultat för {query}",
-    "Press enter to start searching" : "Tryck på enter för att börja söka",
     "Start typing to search" : "Börja skriva för att söka",
     "Loading more results …" : "Hämtar fler resultat ...",
     "Load more results" : "Hämta fler resultat",
     "Search" : "Sök",
+    "No results for {query}" : "Inga resultat för {query}",
+    "Press enter to start searching" : "Tryck på enter för att börja söka",
     "An error occurred while searching for {type}" : "Ett fel uppstod vid sökning efter {type}",
     "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Ange {minSearchLength} tecken eller mer för att söka","Ange {minSearchLength} tecken eller mer för att söka"],
     "This browser is not supported" : "Den här webbläsaren stöds inte",
@@ -183,8 +196,11 @@ OC.L10N.register(
     "Continue with this unsupported browser" : "Fortsätt med webbläsare som inte stöds",
     "Supported versions" : "Stödda versioner",
     "{name} version {version} and above" : "{name} version {version} och högre",
+    "Open settings menu" : "Öppna inställningsmenyn",
+    "Settings menu" : "Inställningsmeny",
     "Search {types} …" : "Sök {types} …",
     "Settings" : "Inställningar",
+    "Avatar of {fullName}" : "Avatar för {fullName}",
     "Could not load your contacts" : "Det gick inte att läsa in dina kontakter",
     "Search contacts …" : "Sök kontakter ...",
     "No contacts found" : "Inga kontakter hittades",
@@ -226,6 +242,7 @@ OC.L10N.register(
     "Show list view" : "Visa listvy",
     "Show grid view" : "Visa rutnätsvy",
     "Pending" : "Väntar",
+    "Home" : "Hem",
     "Copy to {folder}" : "Kopiera till {folder}",
     "Move to {folder}" : "Flytta till {folder}",
     "Saving …" : "Sparar ...",
@@ -254,6 +271,7 @@ OC.L10N.register(
     "Strong password" : "Starkt lösenord",
     "No action available" : "Ingen åtgärd tillgänglig",
     "Error fetching contact actions" : "Fel vid hämtning av kontakthändelser",
+    "Close \"{dialogTitle}\" dialog" : "Stäng \"{dialogTitle}\"",
     "Non-existing tag #{tag}" : "Icke-existerande tag #{tag}",
     "Restricted" : "Begränsad",
     "Invisible" : "Osynlig",
@@ -322,10 +340,7 @@ OC.L10N.register(
     "Skip to main content" : "Skippa till huvudinnehållet",
     "Skip to navigation of app" : "Skippa till navigering av app",
     "Get your own free account" : "Skaffa ett eget gratiskonto",
-    "%s's homepage" : "%s's hemsida",
-    "Contacts" : "Kontakter",
-    "Contacts menu" : "Kontaktmeny",
-    "Open settings menu" : "Öppna inställningsmenyn",
+    "%s homepage" : "%s hemsida",
     "Confirm your password" : "Bekräfta ditt lösenord",
     "Connect to your account" : "Anslut ditt konto",
     "Please log in before granting %1$s access to your %2$s account." : "Logga in innan du ger %1$s åtkomst till ditt %2$s konto.",
@@ -371,6 +386,7 @@ OC.L10N.register(
     "Detailed logs" : "Detaljerade loggar",
     "Update needed" : "Uppdatering krävs",
     "Please use the command line updater because you have a big instance with more than 50 users." : "Vänligen uppdatera med kommando eftersom du har en stor instans med mer än 50 användare.",
+    "Please use the command line updater because automatic updating is disabled in the config.php." : "Uppdatera via kommandotolken då automatisk uppdatering är inaktiverat i config.php.",
     "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "För hjälp, se  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">dokumentationen</a>.",
     "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Jag vet att om jag fortsätter göra uppdateringen via webbgränssnittet innebär risken att begäran får timeout och kan orsaka dataförluster men att jag har en backup och vet hur instansen återställs i fall fel uppstår.",
     "Upgrade via web on my own risk" : "Uppgradera via webben på min egen risk",
@@ -378,12 +394,10 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Denna %s-instans befinner sig för närvarande i underhållsläge, vilket kan ta ett tag.",
     "This page will refresh itself when the instance is available again." : "Denna sida uppdaterar sig själv när instansen är tillgänglig igen.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Hör av dig till din systemadministratör om detta meddelande fortsätter eller visas oväntat.",
-    "Enter your subscription key to increase the user limit. For more information about Nextcloud Enterprise see our website." : "Ange din subscription-nyckel för att öka användarbegränsningen. Se våran hemsida för mer information om Nextcloud Enterprise.",
+    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Denna community-release av Nextcloud stöds inte och direktnotifikationer är inte tillgängliga.",
     "[%d / %d]: Checking table %s" : "[%d / %d]: Kontrollerar tabell %s",
-    "This server has no working Internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the Internet to enjoy all features." : "Den här servern har ingen fungerande internetuppkoppling: flera slutpunkter kunde inte nås. Det här innebär att några av funktionerna som montering av extern lagring, aviseringar om uppdateringar eller installation av tredjepartsprogram inte fungerar. Åtkomst till filer på distans och skicka e-postmeddelanden kanske inte heller fungerar. Upprätta en anslutning från den här servern till Internet för att njuta av alla funktioner.",
-    "Nextcloud 20 is the last release supporting PHP 7.2. Nextcloud 21 requires at least PHP 7.3." : "Nextcloud 20 är den sista versionen som stöder PHP 7.2. Nextcloud 21 kräver minst PHP 7.3.",
-    "The PHP OPcache module is not properly configured. {linkstart}For better performance it is recommended ↗{linkend} to use the following settings in the <code>php.ini</code>:" : "PHP OPcache-modulen är inte korrekt konfigurerad. {linkstart}För bättre prestanda rekommenderas ↗{linkend} att använda följande inställningar i <code>php.ini</code>:",
-    "Your data directory and files are probably accessible from the Internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Din datamapp och filer är förmodligen tillgängliga från Internet. .htaccess-filen fungerar inte. Det rekommenderas starkt att du konfigurerar din webbserver så att datakatalogen inte längre är tillgänglig eller flyttar datakatalogen utanför dokument root för webbservern.",
+    "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications have been disabled to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at nextcloud.com/enterprise." : "Detta är Nextclouds communitybygge som inte supporteras. Med tanke på storleken på denna instans kan prestanda, tillförlitlighet och skalbarhet inte garanteras. Push-meddelanden har inaktiverats för att undvika överbelastning av vår gratistjänst. Lär dig mer om fördelarna med Nextcloud Enterprise på nextcloud.com/enterprise.",
+    "Nextcloud 23 is the last release supporting PHP 7.3. Nextcloud 24 requires at least PHP 7.4." : "Nextcloud 23 är den sista versionen som stödjer PHP 7.3. Nextcloud 24 kräver minst PHP 7.4.",
     "The \"{header}\" HTTP header doesn't contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "HTTP-rubriken \"{header}\" innehåller inte \"{expected}\". Det innebär en potentiell säkerhetsrisk. Det är rekommenderat att ändra inställningen.",
     "Collaboratively edit office documents." : "Redigera dokument tillsammans.",
     "Local document editing back-end used by the Collabora Online app." : "Lokal dokumentredigering back-end som används av Collabora Online-appen.",
@@ -393,12 +407,8 @@ OC.L10N.register(
     "The document could not be found on the server. Maybe the share was deleted or has expired?" : "Dokumentet kunde inte hittas på servern. Kanske var delningen raderad eller har gått ut?",
     "More" : "Mer",
     "More apps menu" : "Fler appar - meny",
-    "Settings menu" : "Inställningsmeny",
-    "The password is wrong. Try again." : "Felaktigt lösenord. Försök igen.",
-    "Setup two-factor authentication" : "Ställ in tvåfaktorsautentisering",
-    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Denna community-release av Nextcloud stöds inte och direktnotifikationer är inte tillgängliga.",
-    "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications have been disabled to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at nextcloud.com/enterprise." : "Detta är Nextclouds communitybygge som inte supporteras. Med tanke på storleken på denna instans kan prestanda, tillförlitlighet och skalbarhet inte garanteras. Push-meddelanden har inaktiverats för att undvika överbelastning av vår gratistjänst. Lär dig mer om fördelarna med Nextcloud Enterprise på nextcloud.com/enterprise.",
-    "You haven't added any info yet" : "Du har inte angivit någon information ännu",
-    "{user} hasn't added any info yet" : "{user} har inte angivit någon information ännu"
+    "Contacts" : "Kontakter",
+    "Contacts menu" : "Kontaktmeny",
+    "Setup two-factor authentication" : "Ställ in tvåfaktorsautentisering"
 },
 "nplurals=2; plural=(n != 1);");
