@@ -56,7 +56,9 @@ OC.L10N.register(
     "Unknown filetype" : "不明なファイルタイプ",
     "Invalid image" : "無効な画像",
     "Avatar image is not square" : "アバター画像が正方形ではありません",
+    "Files" : "ファイル",
     "View profile" : "プロフィールを表示",
+    "Local time: %s" : "現地時間: %s",
     "today" : "今日",
     "tomorrow" : "明日",
     "yesterday" : "昨日",
@@ -101,6 +103,8 @@ OC.L10N.register(
     "Users" : "ユーザー",
     "Email" : "メール",
     "Mail %s" : "メール %s",
+    "Fediverse" : "フェディバース",
+    "View %s on the fediverse" : "%sをフェディバース上で見る",
     "Phone" : "携帯",
     "Call %s" : "電話 %s",
     "Twitter" : "Twitter",
@@ -127,6 +131,8 @@ OC.L10N.register(
     "PostgreSQL username and/or password not valid" : "PostgreSQLのユーザー名またはパスワードが有効ではありません",
     "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X では、サポートされていません。このOSでは、%sは正常に動作しないかもしれません。ご自身の責任においてご利用ください。",
     "For the best results, please consider using a GNU/Linux server instead." : "最も良い方法としては、代わりにGNU/Linuxサーバーを利用することをご検討ください。",
+    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "このインスタンス %s は、32bit PHP 環境で動作しており、php.ini に open_basedir が設定されているようです。4GB以上のファイルで問題が発生するため、この設定を利用しないことをお勧めします。",
+    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "php.ini から open_basedir 設定を削除するか、64bit PHPに切り替えてください。",
     "Set an admin username." : "管理者のユーザー名を設定",
     "Set an admin password." : "管理者のパスワードを設定",
     "Cannot create or write into the data directory %s" : " データディレクトリ%sに作成、書き込みができません",
@@ -150,7 +156,7 @@ OC.L10N.register(
     "%1$s shared »%2$s« with you." : "%1$sが あなたと »%2$s« を共有しました。",
     "Click the button below to open it." : "開くには下のボタンをクリック",
     "The requested share does not exist anymore" : "この共有はもう存在しません。",
-    "The user limit has been reached and the user was not created. Check your notifications to learn more." : "ユーザー制限に達したため、ユーザーは作成されませんでした。詳細については、通知を確認してください。",
+    "The user was not created because the user limit has been reached. Check your notifications to learn more." : "登録可能なユーザー数の上限に達したため、ユーザーは作成されませんでした。詳細については通知をご確認ください。",
     "Could not find category \"%s\"" : "カテゴリ \"%s\" が見つかりませんでした",
     "Sunday" : "日曜日",
     "Monday" : "月曜日",
@@ -197,14 +203,14 @@ OC.L10N.register(
     "Oct." : "10月",
     "Nov." : "11月",
     "Dec." : "12月",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "ユーザー名で利用できる文字列： \"a-z\", \"A-Z\", \"0-9\", \"_.@-\"",
+    "A valid password must be provided" : "有効なパスワードを指定する必要があります",
+    "The username is already being used" : "このユーザー名はすでに使われています",
+    "Could not create user" : "ユーザーを作成できませんでした",
+    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "ユーザー名で利用できる文字列： \"a-z\", \"A-Z\", \"0-9\", スペース, \"_.@-\"",
     "A valid username must be provided" : "有効なユーザー名を指定する必要があります",
     "Username contains whitespace at the beginning or at the end" : "ユーザー名の最初か最後に空白が含まれています",
     "Username must not consist of dots only" : "ユーザー名に、ドットのみはつけられません",
     "Username is invalid because files already exist for this user" : "このユーザーのファイルが既に存在するため、このユーザー名は使用できません",
-    "A valid password must be provided" : "有効なパスワードを指定する必要があります",
-    "The username is already being used" : "このユーザー名はすでに使われています",
-    "Could not create user" : "ユーザーを作成できませんでした",
     "User disabled" : "ユーザーは無効です",
     "Login canceled by app" : "アプリによりログインが中止されました",
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "次の依存関係を満たしていないため、アプリ \"%1$s\" をインストールできません: %2$s",
@@ -259,31 +265,11 @@ OC.L10N.register(
     "Storage connection error. %s" : "ストレージへの接続エラー｡ %s",
     "Storage is temporarily not available" : "ストレージは一時的に利用できません",
     "Storage connection timeout. %s" : "ストレージへの接続がタイムアウト。 %s",
-    "This can usually be fixed by giving the webserver write access to the config directory." : "Webサーバーにconfigディレクトリへの書き込み権限を与えることで解決する可能性があります。",
     "%s enter the database username and name." : "%s データベース名とデータベースのユーザー名を入力してください。",
     "%s enter the database username." : "%s のデータベースのユーザー名を入力してください。",
     "%s enter the database name." : "%s のデータベース名を入力してください。",
     "%s you may not use dots in the database name" : "%s ではデータベース名にドットを利用できないかもしれません。",
-    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "このインスタンス %s は、32bit PHP 環境で動作しており、php.ini に open_basedir が設定されているようです。4GB以上のファイルで問題が発生するため、この設定を利用しないことをお勧めします。",
-    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "php.ini から open_basedir 設定を削除するか、64bit PHPに切り替えてください。",
-    "The user limit has been reached and the user was not created." : "ユーザー数の上限に達したためユーザーを作成出来ませんでした。",
-    "Cannot read file" : "ファイルを読み込めません",
-    "Cannot write into \"config\" directory" : "\"config\" ディレクトリに書き込みができません",
-    "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "多くの場合、Webサーバーの configディレクトリ に書き込み権限を与えることで直ります。%s を見てください",
-    "Cannot write into \"apps\" directory" : "\"apps\" ディレクトリに書き込みができません",
-    "This can usually be fixed by giving the webserver write access to the apps directory or disabling the App Store in the config file." : "Webサーバーにappsディレクトリへの書き込み権限を許可するか、構成ファイルでAppStoreを無効にすることで解決する可能性があります。",
-    "Cannot create \"data\" directory" : "\"data\" ディレクトリを作成できません",
-    "This can usually be fixed by giving the webserver write access to the root directory. See %s" : "多くの場合、Webサーバーのルートディレクトリに書き込み権限を与えることで直ります。詳しくは%sを確認してください。",
-    "Permissions can usually be fixed by giving the webserver write access to the root directory. See %s." : "Webサーバーのルートディレクトリに書き込み権限パーミッションが必要です。詳しくは%sを確認してください。",
-    "Setting locale to %s failed" : "ロケールを %s に設定できませんでした",
-    "Please install one of these locales on your system and restart your webserver." : "これらのロケールのうちいずれかをシステムにインストールし、Webサーバーを再起動してください。",
-    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload の値は \"0\" であるべきですが、\"%s\" に設定されています",
-    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "この問題を修正するには、php.ini ファイルの <code>mbstring.func_overload</code> を <code>0</code> に設定してください。",
-    "PostgreSQL >= 9 required" : "PostgreSQL 9以上が必要です",
-    "Please upgrade your database version" : "新しいバージョンのデータベースにアップグレードしてください",
-    "Your data directory is readable by other users" : "データディレクトリは、他のユーザーから読み取り専用です",
-    "Your data directory must be an absolute path" : "データディレクトリは、絶対パスにする必要があります",
-    "Check the value of \"datadirectory\" in your configuration" : "設定ファイル内の \"datadirectory\" の値を確認してください。",
-    "Your data directory is invalid" : "データディレクトリが無効です"
+    "The user limit has been reached and the user was not created. Check your notifications to learn more." : "ユーザー制限に達したため、ユーザーは作成されませんでした。詳細については、通知を確認してください。",
+    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "ユーザー名で利用できる文字列： \"a-z\", \"A-Z\", \"0-9\", \"_.@-\""
 },
 "nplurals=1; plural=0;");
