@@ -4,10 +4,12 @@
  *
  * @author Arthur Schiwon <blizzz@arthur-schiwon.de>
  * @author Bart Visscher <bartv@thisnet.nl>
- * @author Björn Schießle <bjoern@schiessle.org>
+ * @author Christoph Wurst <christoph@winzerhof-wurst.at>
+ * @author Greta Doci <gretadoci@gmail.com>
  * @author hkjolhede <hkjolhede@gmail.com>
  * @author Joas Schilling <coding@schilljs.com>
  * @author Jörn Friedrich Dreyer <jfd@butonic.de>
+ * @author Julius Härtl <jus@bitgrid.net>
  * @author Lukas Reschke <lukas@statuscode.ch>
  * @author Martin Mattel <martin.mattel@diemattels.at>
  * @author Michael Gapczynski <GapczynskiM@gmail.com>
@@ -15,11 +17,13 @@
  * @author Robin Appelman <robin@icewind.nl>
  * @author Robin McCorkell <robin@mccorkell.me.uk>
  * @author Roeland Jago Douma <roeland@famdouma.nl>
+ * @author Roland Tapken <roland@bitarbeiter.net>
  * @author Sam Tuke <mail@samtuke.com>
  * @author scambra <sergio@entrecables.com>
  * @author Stefan Weil <sw@weilnetz.de>
  * @author Thomas Müller <thomas.mueller@tmit.eu>
- * @author Vincent Petry <pvince81@owncloud.com>
+ * @author Vincent Petry <vincent@nextcloud.com>
+ * @author Vinicius Cubas Brand <vinicius@eita.org.br>
  *
  * @license AGPL-3.0
  *
@@ -33,24 +37,33 @@
  * GNU Affero General Public License for more details.
  *
  * You should have received a copy of the GNU Affero General Public License, version 3,
- * along with this program.  If not, see <http://www.gnu.org/licenses/>
+ * along with this program. If not, see <http://www.gnu.org/licenses/>
  *
  */
-
 namespace OC\Files\Storage;
 
 use OC\Files\Cache\Cache;
 use OC\Files\Cache\Propagator;
 use OC\Files\Cache\Scanner;
 use OC\Files\Cache\Updater;
-use OC\Files\Filesystem;
 use OC\Files\Cache\Watcher;
+use OC\Files\Filesystem;
+use OC\Files\Storage\Wrapper\Jail;
+use OC\Files\Storage\Wrapper\Wrapper;
+use OCP\Files\EmptyFileNameException;
 use OCP\Files\FileNameTooLongException;
+use OCP\Files\ForbiddenException;
+use OCP\Files\GenericFileException;
 use OCP\Files\InvalidCharacterInPathException;
+use OCP\Files\InvalidDirectoryException;
 use OCP\Files\InvalidPathException;
 use OCP\Files\ReservedWordException;
 use OCP\Files\Storage\ILockingStorage;
+use OCP\Files\Storage\IStorage;
+use OCP\Files\Storage\IWriteStreamStorage;
 use OCP\Lock\ILockingProvider;
+use OCP\Lock\LockedException;
+use Psr\Log\LoggerInterface;
 
 /**
  * Storage backend class for providing common filesystem operation methods
@@ -63,8 +76,7 @@ use OCP\Lock\ILockingProvider;
  * Some \OC\Files\Storage\Common methods call functions which are first defined
  * in classes which extend it, e.g. $this->stat() .
  */
-abstract class Common implements Storage, ILockingStorage {
-
+abstract class Common implements Storage, ILockingStorage, IWriteStreamStorage {
 	use LocalTempFileTrait;
 
 	protected $cache;
@@ -77,6 +89,11 @@ abstract class Common implements Storage, ILockingStorage {
 	protected $mountOptions = [];
 	protected $owner = null;
 
+	/** @var ?bool */
+	private $shouldLogLocks = null;
+	/** @var ?LoggerInterface */
+	private $logger;
+
 	public function __construct($parameters) {
 	}
 
@@ -89,7 +106,7 @@ abstract class Common implements Storage, ILockingStorage {
 	protected function remove($path) {
 		if ($this->is_dir($path)) {
 			return $this->rmdir($path);
-		} else if ($this->is_file($path)) {
+		} elseif ($this->is_file($path)) {
 			return $this->unlink($path);
 		} else {
 			return false;
@@ -104,7 +121,7 @@ abstract class Common implements Storage, ILockingStorage {
 		return $this->filetype($path) === 'file';
 	}
 
-	public function filesize($path) {
+	public function filesize($path): false|int|float {
 		if ($this->is_dir($path)) {
 			return 0; //by definition
 		} else {
@@ -139,7 +156,7 @@ abstract class Common implements Storage, ILockingStorage {
 
 	public function isDeletable($path) {
 		if ($path === '' || $path === '/') {
-			return false;
+			return $this->isUpdatable($path);
 		}
 		$parent = dirname($path);
 		return $this->isUpdatable($parent) && $this->isUpdatable($path);
@@ -196,21 +213,22 @@ abstract class Common implements Storage, ILockingStorage {
 		return $count;
 	}
 
-	public function rename($path1, $path2) {
-		$this->remove($path2);
+	public function rename($source, $target) {
+		$this->remove($target);
 
-		$this->removeCachedFile($path1);
-		return $this->copy($path1, $path2) and $this->remove($path1);
+		$this->removeCachedFile($source);
+		return $this->copy($source, $target) and $this->remove($source);
 	}
 
-	public function copy($path1, $path2) {
-		if ($this->is_dir($path1)) {
-			$this->remove($path2);
-			$dir = $this->opendir($path1);
-			$this->mkdir($path2);
+	public function copy($source, $target) {
+		if ($this->is_dir($source)) {
+			$this->remove($target);
+			$dir = $this->opendir($source);
+			$this->mkdir($target);
 			while ($file = readdir($dir)) {
 				if (!Filesystem::isIgnoredDir($file)) {
-					if (!$this->copy($path1 . '/' . $file, $path2 . '/' . $file)) {
+					if (!$this->copy($source . '/' . $file, $target . '/' . $file)) {
+						closedir($dir);
 						return false;
 					}
 				}
@@ -218,10 +236,13 @@ abstract class Common implements Storage, ILockingStorage {
 			closedir($dir);
 			return true;
 		} else {
-			$source = $this->fopen($path1, 'r');
-			$target = $this->fopen($path2, 'w');
-			list(, $result) = \OC_Helper::streamCopy($source, $target);
-			$this->removeCachedFile($path2);
+			$sourceStream = $this->fopen($source, 'r');
+			$targetStream = $this->fopen($target, 'w');
+			[, $result] = \OC_Helper::streamCopy($sourceStream, $targetStream);
+			if (!$result) {
+				\OCP\Server::get(LoggerInterface::class)->warning("Failed to write data while copying $source to $target");
+			}
+			$this->removeCachedFile($target);
 			return $result;
 		}
 	}
@@ -279,11 +300,13 @@ abstract class Common implements Storage, ILockingStorage {
 	 * @return array
 	 */
 	protected function searchInDir($query, $dir = '') {
-		$files = array();
+		$files = [];
 		$dh = $this->opendir($dir);
 		if (is_resource($dh)) {
 			while (($item = readdir($dh)) !== false) {
-				if (\OC\Files\Filesystem::isIgnoredDir($item)) continue;
+				if (\OC\Files\Filesystem::isIgnoredDir($item)) {
+					continue;
+				}
 				if (strstr(strtolower($item), strtolower($query)) !== false) {
 					$files[] = $dir . '/' . $item;
 				}
@@ -297,12 +320,12 @@ abstract class Common implements Storage, ILockingStorage {
 	}
 
 	/**
-	 * check if a file or folder has been updated since $time
+	 * Check if a file or folder has been updated since $time
 	 *
 	 * The method is only used to check if the cache needs to be updated. Storage backends that don't support checking
 	 * the mtime should always return false here. As a result storage implementations that always return false expect
 	 * exclusive access to the backend and will not pick up files that have been added in a way that circumvents
-	 * ownClouds filesystem.
+	 * Nextcloud filesystem.
 	 *
 	 * @param string $path
 	 * @param int $time
@@ -355,7 +378,8 @@ abstract class Common implements Storage, ILockingStorage {
 			$storage = $this;
 		}
 		if (!isset($storage->propagator)) {
-			$storage->propagator = new Propagator($storage, \OC::$server->getDatabaseConnection());
+			$config = \OC::$server->getSystemConfig();
+			$storage->propagator = new Propagator($storage, \OC::$server->getDatabaseConnection(), ['appdata_' . $config->getValue('instanceid')]);
 		}
 		return $storage->propagator;
 	}
@@ -416,11 +440,11 @@ abstract class Common implements Storage, ILockingStorage {
 			$path = '/' . $path;
 		}
 
-		$output = array();
+		$output = [];
 		foreach (explode('/', $path) as $chunk) {
 			if ($chunk == '..') {
 				array_pop($output);
-			} else if ($chunk == '.') {
+			} elseif ($chunk == '.') {
 			} else {
 				$output[] = $chunk;
 			}
@@ -434,10 +458,19 @@ abstract class Common implements Storage, ILockingStorage {
 	 * @return bool
 	 */
 	public function test() {
-		if ($this->stat('')) {
-			return true;
+		try {
+			if ($this->stat('')) {
+				return true;
+			}
+			\OC::$server->get(LoggerInterface::class)->info("External storage not available: stat() failed");
+			return false;
+		} catch (\Exception $e) {
+			\OC::$server->get(LoggerInterface::class)->warning(
+				"External storage not available: " . $e->getMessage(),
+				['exception' => $e]
+			);
+			return false;
 		}
-		return false;
 	}
 
 	/**
@@ -466,6 +499,10 @@ abstract class Common implements Storage, ILockingStorage {
 	 * @return bool
 	 */
 	public function instanceOfStorage($class) {
+		if (ltrim($class, '\\') === 'OC\Files\Storage\Shared') {
+			// FIXME Temporary fix to keep existing checks working
+			$class = '\OCA\Files_Sharing\SharedStorage';
+		}
 		return is_a($this, $class);
 	}
 
@@ -483,9 +520,33 @@ abstract class Common implements Storage, ILockingStorage {
 
 	/**
 	 * @inheritdoc
+	 * @throws InvalidPathException
 	 */
 	public function verifyPath($path, $fileName) {
-		if (isset($fileName[255])) {
+		// verify empty and dot files
+		$trimmed = trim($fileName);
+		if ($trimmed === '') {
+			throw new EmptyFileNameException();
+		}
+
+		if (\OC\Files\Filesystem::isIgnoredDir($trimmed)) {
+			throw new InvalidDirectoryException();
+		}
+
+		if (!\OC::$server->getDatabaseConnection()->supports4ByteText()) {
+			// verify database - e.g. mysql only 3-byte chars
+			if (preg_match('%(?:
+      \xF0[\x90-\xBF][\x80-\xBF]{2}      # planes 1-3
+    | [\xF1-\xF3][\x80-\xBF]{3}          # planes 4-15
+    | \xF4[\x80-\x8F][\x80-\xBF]{2}      # plane 16
+)%xs', $fileName)) {
+				throw new InvalidCharacterInPathException();
+			}
+		}
+
+		// 255 characters is the limit on common file systems (ext/xfs)
+		// oc_filecache has a 250 char length limit for the filename
+		if (isset($fileName[250])) {
 			throw new FileNameTooLongException();
 		}
 
@@ -498,8 +559,8 @@ abstract class Common implements Storage, ILockingStorage {
 	 * @throws InvalidPathException
 	 */
 	protected function verifyPosixPath($fileName) {
-		$fileName = trim($fileName);
 		$this->scanForInvalidCharacters($fileName, "\\/");
+		$fileName = trim($fileName);
 		$reservedNames = ['*'];
 		if (in_array($fileName, $reservedNames)) {
 			throw new ReservedWordException();
@@ -541,13 +602,13 @@ abstract class Common implements Storage, ILockingStorage {
 	}
 
 	/**
-	 * @param \OCP\Files\Storage $sourceStorage
+	 * @param IStorage $sourceStorage
 	 * @param string $sourceInternalPath
 	 * @param string $targetInternalPath
 	 * @param bool $preserveMtime
 	 * @return bool
 	 */
-	public function copyFromStorage(\OCP\Files\Storage $sourceStorage, $sourceInternalPath, $targetInternalPath, $preserveMtime = false) {
+	public function copyFromStorage(IStorage $sourceStorage, $sourceInternalPath, $targetInternalPath, $preserveMtime = false) {
 		if ($sourceStorage === $this) {
 			return $this->copy($sourceInternalPath, $targetInternalPath);
 		}
@@ -556,6 +617,7 @@ abstract class Common implements Storage, ILockingStorage {
 			$dh = $sourceStorage->opendir($sourceInternalPath);
 			$result = $this->mkdir($targetInternalPath);
 			if (is_resource($dh)) {
+				$result = true;
 				while ($result and ($file = readdir($dh)) !== false) {
 					if (!Filesystem::isIgnoredDir($file)) {
 						$result &= $this->copyFromStorage($sourceStorage, $sourceInternalPath . '/' . $file, $targetInternalPath . '/' . $file);
@@ -564,18 +626,20 @@ abstract class Common implements Storage, ILockingStorage {
 			}
 		} else {
 			$source = $sourceStorage->fopen($sourceInternalPath, 'r');
-			// TODO: call fopen in a way that we execute again all storage wrappers
-			// to avoid that we bypass storage wrappers which perform important actions
-			// for this operation. Same is true for all other operations which
-			// are not the same as the original one.Once this is fixed we also
-			// need to adjust the encryption wrapper.
-			$target = $this->fopen($targetInternalPath, 'w');
-			list(, $result) = \OC_Helper::streamCopy($source, $target);
-			if ($result and $preserveMtime) {
-				$this->touch($targetInternalPath, $sourceStorage->filemtime($sourceInternalPath));
+			$result = false;
+			if ($source) {
+				try {
+					$this->writeStream($targetInternalPath, $source);
+					$result = true;
+				} catch (\Exception $e) {
+					\OC::$server->get(LoggerInterface::class)->warning('Failed to copy stream to storage', ['exception' => $e]);
+				}
+			}
+
+			if ($result && $preserveMtime) {
+				$mtime = $sourceStorage->filemtime($sourceInternalPath);
+				$this->touch($targetInternalPath, is_int($mtime) ? $mtime : null);
 			}
-			fclose($source);
-			fclose($target);
 
 			if (!$result) {
 				// delete partially written target file
@@ -588,13 +652,39 @@ abstract class Common implements Storage, ILockingStorage {
 	}
 
 	/**
-	 * @param \OCP\Files\Storage $sourceStorage
+	 * Check if a storage is the same as the current one, including wrapped storages
+	 *
+	 * @param IStorage $storage
+	 * @return bool
+	 */
+	private function isSameStorage(IStorage $storage): bool {
+		while ($storage->instanceOfStorage(Wrapper::class)) {
+			/**
+			 * @var Wrapper $sourceStorage
+			 */
+			$storage = $storage->getWrapperStorage();
+		}
+
+		return $storage === $this;
+	}
+
+	/**
+	 * @param IStorage $sourceStorage
 	 * @param string $sourceInternalPath
 	 * @param string $targetInternalPath
 	 * @return bool
 	 */
-	public function moveFromStorage(\OCP\Files\Storage $sourceStorage, $sourceInternalPath, $targetInternalPath) {
-		if ($sourceStorage === $this) {
+	public function moveFromStorage(IStorage $sourceStorage, $sourceInternalPath, $targetInternalPath) {
+		if ($this->isSameStorage($sourceStorage)) {
+			// resolve any jailed paths
+			while ($sourceStorage->instanceOfStorage(Jail::class)) {
+				/**
+				 * @var Jail $sourceStorage
+				 */
+				$sourceInternalPath = $sourceStorage->getUnjailedPath($sourceInternalPath);
+				$sourceStorage = $sourceStorage->getUnjailedStorage();
+			}
+
 			return $this->rename($sourceInternalPath, $targetInternalPath);
 		}
 
@@ -605,9 +695,9 @@ abstract class Common implements Storage, ILockingStorage {
 		$result = $this->copyFromStorage($sourceStorage, $sourceInternalPath, $targetInternalPath, true);
 		if ($result) {
 			if ($sourceStorage->is_dir($sourceInternalPath)) {
-				$result &= $sourceStorage->rmdir($sourceInternalPath);
+				$result = $sourceStorage->rmdir($sourceInternalPath);
 			} else {
-				$result &= $sourceStorage->unlink($sourceInternalPath);
+				$result = $sourceStorage->unlink($sourceInternalPath);
 			}
 		}
 		return $result;
@@ -617,6 +707,10 @@ abstract class Common implements Storage, ILockingStorage {
 	 * @inheritdoc
 	 */
 	public function getMetaData($path) {
+		if (Filesystem::isFileBlacklisted($path)) {
+			throw new ForbiddenException('Invalid path: ' . $path, false);
+		}
+
 		$permissions = $this->getPermissions($path);
 		if (!$permissions & \OCP\Constants::PERMISSION_READ) {
 			//can't read, nothing we can do
@@ -637,6 +731,7 @@ abstract class Common implements Storage, ILockingStorage {
 		$data['etag'] = $this->getETag($path);
 		$data['storage_mtime'] = $data['mtime'];
 		$data['permissions'] = $permissions;
+		$data['name'] = basename($path);
 
 		return $data;
 	}
@@ -648,25 +743,101 @@ abstract class Common implements Storage, ILockingStorage {
 	 * @throws \OCP\Lock\LockedException
 	 */
 	public function acquireLock($path, $type, ILockingProvider $provider) {
-		$provider->acquireLock('files/' . md5($this->getId() . '::' . trim($path, '/')), $type);
+		$logger = $this->getLockLogger();
+		if ($logger) {
+			$typeString = ($type === ILockingProvider::LOCK_SHARED) ? 'shared' : 'exclusive';
+			$logger->info(
+				sprintf(
+					'acquire %s lock on "%s" on storage "%s"',
+					$typeString,
+					$path,
+					$this->getId()
+				),
+				[
+					'app' => 'locking',
+				]
+			);
+		}
+		try {
+			$provider->acquireLock('files/' . md5($this->getId() . '::' . trim($path, '/')), $type, $this->getId() . '::' . $path);
+		} catch (LockedException $e) {
+			if ($logger) {
+				$logger->info($e->getMessage(), ['exception' => $e]);
+			}
+			throw $e;
+		}
 	}
 
 	/**
 	 * @param string $path
 	 * @param int $type \OCP\Lock\ILockingProvider::LOCK_SHARED or \OCP\Lock\ILockingProvider::LOCK_EXCLUSIVE
 	 * @param \OCP\Lock\ILockingProvider $provider
+	 * @throws \OCP\Lock\LockedException
 	 */
 	public function releaseLock($path, $type, ILockingProvider $provider) {
-		$provider->releaseLock('files/' . md5($this->getId() . '::' . trim($path, '/')), $type);
+		$logger = $this->getLockLogger();
+		if ($logger) {
+			$typeString = ($type === ILockingProvider::LOCK_SHARED) ? 'shared' : 'exclusive';
+			$logger->info(
+				sprintf(
+					'release %s lock on "%s" on storage "%s"',
+					$typeString,
+					$path,
+					$this->getId()
+				),
+				[
+					'app' => 'locking',
+				]
+			);
+		}
+		try {
+			$provider->releaseLock('files/' . md5($this->getId() . '::' . trim($path, '/')), $type);
+		} catch (LockedException $e) {
+			if ($logger) {
+				$logger->info($e->getMessage(), ['exception' => $e]);
+			}
+			throw $e;
+		}
 	}
 
 	/**
 	 * @param string $path
 	 * @param int $type \OCP\Lock\ILockingProvider::LOCK_SHARED or \OCP\Lock\ILockingProvider::LOCK_EXCLUSIVE
 	 * @param \OCP\Lock\ILockingProvider $provider
+	 * @throws \OCP\Lock\LockedException
 	 */
 	public function changeLock($path, $type, ILockingProvider $provider) {
-		$provider->changeLock('files/' . md5($this->getId() . '::' . trim($path, '/')), $type);
+		$logger = $this->getLockLogger();
+		if ($logger) {
+			$typeString = ($type === ILockingProvider::LOCK_SHARED) ? 'shared' : 'exclusive';
+			$logger->info(
+				sprintf(
+					'change lock on "%s" to %s on storage "%s"',
+					$path,
+					$typeString,
+					$this->getId()
+				),
+				[
+					'app' => 'locking',
+				]
+			);
+		}
+		try {
+			$provider->changeLock('files/' . md5($this->getId() . '::' . trim($path, '/')), $type);
+		} catch (LockedException $e) {
+			if ($logger) {
+				$logger->info($e->getMessage(), ['exception' => $e]);
+			}
+			throw $e;
+		}
+	}
+
+	private function getLockLogger(): ?LoggerInterface {
+		if (is_null($this->shouldLogLocks)) {
+			$this->shouldLogLocks = \OC::$server->getConfig()->getSystemValue('filelocking.debug', false);
+			$this->logger = $this->shouldLogLocks ? \OC::$server->get(LoggerInterface::class) : null;
+		}
+		return $this->logger;
 	}
 
 	/**
@@ -682,4 +853,52 @@ abstract class Common implements Storage, ILockingStorage {
 	public function setAvailability($isAvailable) {
 		$this->getStorageCache()->setAvailability($isAvailable);
 	}
+
+	/**
+	 * @return bool
+	 */
+	public function needsPartFile() {
+		return true;
+	}
+
+	/**
+	 * fallback implementation
+	 *
+	 * @param string $path
+	 * @param resource $stream
+	 * @param int $size
+	 * @return int
+	 */
+	public function writeStream(string $path, $stream, int $size = null): int {
+		$target = $this->fopen($path, 'w');
+		if (!$target) {
+			throw new GenericFileException("Failed to open $path for writing");
+		}
+		try {
+			[$count, $result] = \OC_Helper::streamCopy($stream, $target);
+			if (!$result) {
+				throw new GenericFileException("Failed to copy stream");
+			}
+		} finally {
+			fclose($target);
+			fclose($stream);
+		}
+		return $count;
+	}
+
+	public function getDirectoryContent($directory): \Traversable {
+		$dh = $this->opendir($directory);
+		if (is_resource($dh)) {
+			$basePath = rtrim($directory, '/');
+			while (($file = readdir($dh)) !== false) {
+				if (!Filesystem::isIgnoredDir($file)) {
+					$childPath = $basePath . '/' . trim($file, '/');
+					$metadata = $this->getMetaData($childPath);
+					if ($metadata !== null) {
+						yield $metadata;
+					}
+				}
+			}
+		}
+	}
 }
