@@ -49,8 +49,8 @@ namespace OC\Files;
 use Icewind\Streams\CallbackWrapper;
 use OC\Files\Mount\MoveableMount;
 use OC\Files\Storage\Storage;
-use OC\User\DisplayNameCache;
 use OC\User\LazyUser;
+use OC\Share\Share;
 use OC\User\User;
 use OCA\Files_Sharing\SharedMount;
 use OCP\Constants;
@@ -64,10 +64,10 @@ use OCP\Files\Mount\IMountPoint;
 use OCP\Files\NotFoundException;
 use OCP\Files\ReservedWordException;
 use OCP\Files\Storage\IStorage;
-use OCP\ILogger;
 use OCP\IUser;
 use OCP\Lock\ILockingProvider;
 use OCP\Lock\LockedException;
+use Psr\Log\LoggerInterface;
 
 /**
  * Class to provide access to ownCloud filesystem via a "view", and methods for
@@ -101,10 +101,7 @@ class View {
 	/** @var \OC\User\Manager */
 	private $userManager;
 
-	/** @var \OCP\ILogger */
-	private $logger;
-
-	private DisplayNameCache $displayNameCache;
+	private LoggerInterface $logger;
 
 	/**
 	 * @param string $root
@@ -122,8 +119,7 @@ class View {
 		$this->lockingProvider = \OC::$server->getLockingProvider();
 		$this->lockingEnabled = !($this->lockingProvider instanceof \OC\Lock\NoopLockingProvider);
 		$this->userManager = \OC::$server->getUserManager();
-		$this->displayNameCache = \OC::$server->get(DisplayNameCache::class);
-		$this->logger = \OC::$server->getLogger();
+		$this->logger = \OC::$server->get(LoggerInterface::class);
 	}
 
 	public function getAbsolutePath($path = '/') {
@@ -168,7 +164,7 @@ class View {
 	 * get path relative to the root of the view
 	 *
 	 * @param string $path
-	 * @return string
+	 * @return ?string
 	 */
 	public function getRelativePath($path) {
 		$this->assertPathLength($path);
@@ -415,7 +411,7 @@ class View {
 	 * @param string $path
 	 * @return mixed
 	 */
-	public function filesize($path) {
+	public function filesize(string $path) {
 		return $this->basicOperation('filesize', $path);
 	}
 
@@ -579,7 +575,7 @@ class View {
 		try {
 			$result = $this->basicOperation('touch', $path, $hooks, $mtime);
 		} catch (\Exception $e) {
-			$this->logger->logException($e, ['level' => ILogger::INFO, 'message' => 'Error while setting modified time']);
+			$this->logger->info('Error while setting modified time', ['app' => 'core', 'exception' => $e]);
 			$result = false;
 		}
 		if (!$result) {
@@ -753,65 +749,65 @@ class View {
 	/**
 	 * Rename/move a file or folder from the source path to target path.
 	 *
-	 * @param string $path1 source path
-	 * @param string $path2 target path
+	 * @param string $source source path
+	 * @param string $target target path
 	 *
 	 * @return bool|mixed
 	 * @throws LockedException
 	 */
-	public function rename($path1, $path2) {
-		$absolutePath1 = Filesystem::normalizePath($this->getAbsolutePath($path1));
-		$absolutePath2 = Filesystem::normalizePath($this->getAbsolutePath($path2));
+	public function rename($source, $target) {
+		$absolutePath1 = Filesystem::normalizePath($this->getAbsolutePath($source));
+		$absolutePath2 = Filesystem::normalizePath($this->getAbsolutePath($target));
 		$result = false;
 		if (
-			Filesystem::isValidPath($path2)
-			and Filesystem::isValidPath($path1)
-			and !Filesystem::isFileBlacklisted($path2)
+			Filesystem::isValidPath($target)
+			and Filesystem::isValidPath($source)
+			and !Filesystem::isFileBlacklisted($target)
 		) {
-			$path1 = $this->getRelativePath($absolutePath1);
-			$path2 = $this->getRelativePath($absolutePath2);
-			$exists = $this->file_exists($path2);
+			$source = $this->getRelativePath($absolutePath1);
+			$target = $this->getRelativePath($absolutePath2);
+			$exists = $this->file_exists($target);
 
-			if ($path1 == null or $path2 == null) {
+			if ($source == null or $target == null) {
 				return false;
 			}
 
-			$this->lockFile($path1, ILockingProvider::LOCK_SHARED, true);
+			$this->lockFile($source, ILockingProvider::LOCK_SHARED, true);
 			try {
-				$this->lockFile($path2, ILockingProvider::LOCK_SHARED, true);
+				$this->lockFile($target, ILockingProvider::LOCK_SHARED, true);
 
 				$run = true;
-				if ($this->shouldEmitHooks($path1) && (Cache\Scanner::isPartialFile($path1) && !Cache\Scanner::isPartialFile($path2))) {
+				if ($this->shouldEmitHooks($source) && (Cache\Scanner::isPartialFile($source) && !Cache\Scanner::isPartialFile($target))) {
 					// if it was a rename from a part file to a regular file it was a write and not a rename operation
-					$this->emit_file_hooks_pre($exists, $path2, $run);
-				} elseif ($this->shouldEmitHooks($path1)) {
+					$this->emit_file_hooks_pre($exists, $target, $run);
+				} elseif ($this->shouldEmitHooks($source)) {
 					\OC_Hook::emit(
 						Filesystem::CLASSNAME, Filesystem::signal_rename,
 						[
-							Filesystem::signal_param_oldpath => $this->getHookPath($path1),
-							Filesystem::signal_param_newpath => $this->getHookPath($path2),
+							Filesystem::signal_param_oldpath => $this->getHookPath($source),
+							Filesystem::signal_param_newpath => $this->getHookPath($target),
 							Filesystem::signal_param_run => &$run
 						]
 					);
 				}
 				if ($run) {
-					$this->verifyPath(dirname($path2), basename($path2));
+					$this->verifyPath(dirname($target), basename($target));
 
 					$manager = Filesystem::getMountManager();
-					$mount1 = $this->getMount($path1);
-					$mount2 = $this->getMount($path2);
+					$mount1 = $this->getMount($source);
+					$mount2 = $this->getMount($target);
 					$storage1 = $mount1->getStorage();
 					$storage2 = $mount2->getStorage();
 					$internalPath1 = $mount1->getInternalPath($absolutePath1);
 					$internalPath2 = $mount2->getInternalPath($absolutePath2);
 
-					$this->changeLock($path1, ILockingProvider::LOCK_EXCLUSIVE, true);
+					$this->changeLock($source, ILockingProvider::LOCK_EXCLUSIVE, true);
 					try {
-						$this->changeLock($path2, ILockingProvider::LOCK_EXCLUSIVE, true);
+						$this->changeLock($target, ILockingProvider::LOCK_EXCLUSIVE, true);
 
 						if ($internalPath1 === '') {
 							if ($mount1 instanceof MoveableMount) {
-								$sourceParentMount = $this->getMount(dirname($path1));
+								$sourceParentMount = $this->getMount(dirname($source));
 								if ($sourceParentMount === $mount2 && $this->targetIsNotShared($storage2, $internalPath2)) {
 									/**
 									 * @var \OC\Files\Mount\MountPoint | \OC\Files\Mount\MoveableMount $mount1
@@ -825,19 +821,19 @@ class View {
 							} else {
 								$result = false;
 							}
-							// moving a file/folder within the same mount point
+						// moving a file/folder within the same mount point
 						} elseif ($storage1 === $storage2) {
 							if ($storage1) {
 								$result = $storage1->rename($internalPath1, $internalPath2);
 							} else {
 								$result = false;
 							}
-							// moving a file/folder between storages (from $storage1 to $storage2)
+						// moving a file/folder between storages (from $storage1 to $storage2)
 						} else {
 							$result = $storage2->moveFromStorage($storage1, $internalPath1, $internalPath2);
 						}
 
-						if ((Cache\Scanner::isPartialFile($path1) && !Cache\Scanner::isPartialFile($path2)) && $result !== false) {
+						if ((Cache\Scanner::isPartialFile($source) && !Cache\Scanner::isPartialFile($target)) && $result !== false) {
 							// if it was a rename from a part file to a regular file it was a write and not a rename operation
 							$this->writeUpdate($storage2, $internalPath2);
 						} elseif ($result) {
@@ -848,22 +844,22 @@ class View {
 					} catch (\Exception $e) {
 						throw $e;
 					} finally {
-						$this->changeLock($path1, ILockingProvider::LOCK_SHARED, true);
-						$this->changeLock($path2, ILockingProvider::LOCK_SHARED, true);
+						$this->changeLock($source, ILockingProvider::LOCK_SHARED, true);
+						$this->changeLock($target, ILockingProvider::LOCK_SHARED, true);
 					}
 
-					if ((Cache\Scanner::isPartialFile($path1) && !Cache\Scanner::isPartialFile($path2)) && $result !== false) {
+					if ((Cache\Scanner::isPartialFile($source) && !Cache\Scanner::isPartialFile($target)) && $result !== false) {
 						if ($this->shouldEmitHooks()) {
-							$this->emit_file_hooks_post($exists, $path2);
+							$this->emit_file_hooks_post($exists, $target);
 						}
 					} elseif ($result) {
-						if ($this->shouldEmitHooks($path1) and $this->shouldEmitHooks($path2)) {
+						if ($this->shouldEmitHooks($source) and $this->shouldEmitHooks($target)) {
 							\OC_Hook::emit(
 								Filesystem::CLASSNAME,
 								Filesystem::signal_post_rename,
 								[
-									Filesystem::signal_param_oldpath => $this->getHookPath($path1),
-									Filesystem::signal_param_newpath => $this->getHookPath($path2)
+									Filesystem::signal_param_oldpath => $this->getHookPath($source),
+									Filesystem::signal_param_newpath => $this->getHookPath($target)
 								]
 							);
 						}
@@ -872,8 +868,8 @@ class View {
 			} catch (\Exception $e) {
 				throw $e;
 			} finally {
-				$this->unlockFile($path1, ILockingProvider::LOCK_SHARED, true);
-				$this->unlockFile($path2, ILockingProvider::LOCK_SHARED, true);
+				$this->unlockFile($source, ILockingProvider::LOCK_SHARED, true);
+				$this->unlockFile($target, ILockingProvider::LOCK_SHARED, true);
 			}
 		}
 		return $result;
@@ -882,57 +878,57 @@ class View {
 	/**
 	 * Copy a file/folder from the source path to target path
 	 *
-	 * @param string $path1 source path
-	 * @param string $path2 target path
+	 * @param string $source source path
+	 * @param string $target target path
 	 * @param bool $preserveMtime whether to preserve mtime on the copy
 	 *
 	 * @return bool|mixed
 	 */
-	public function copy($path1, $path2, $preserveMtime = false) {
-		$absolutePath1 = Filesystem::normalizePath($this->getAbsolutePath($path1));
-		$absolutePath2 = Filesystem::normalizePath($this->getAbsolutePath($path2));
+	public function copy($source, $target, $preserveMtime = false) {
+		$absolutePath1 = Filesystem::normalizePath($this->getAbsolutePath($source));
+		$absolutePath2 = Filesystem::normalizePath($this->getAbsolutePath($target));
 		$result = false;
 		if (
-			Filesystem::isValidPath($path2)
-			and Filesystem::isValidPath($path1)
-			and !Filesystem::isFileBlacklisted($path2)
+			Filesystem::isValidPath($target)
+			and Filesystem::isValidPath($source)
+			and !Filesystem::isFileBlacklisted($target)
 		) {
-			$path1 = $this->getRelativePath($absolutePath1);
-			$path2 = $this->getRelativePath($absolutePath2);
+			$source = $this->getRelativePath($absolutePath1);
+			$target = $this->getRelativePath($absolutePath2);
 
-			if ($path1 == null or $path2 == null) {
+			if ($source == null or $target == null) {
 				return false;
 			}
 			$run = true;
 
-			$this->lockFile($path2, ILockingProvider::LOCK_SHARED);
-			$this->lockFile($path1, ILockingProvider::LOCK_SHARED);
+			$this->lockFile($target, ILockingProvider::LOCK_SHARED);
+			$this->lockFile($source, ILockingProvider::LOCK_SHARED);
 			$lockTypePath1 = ILockingProvider::LOCK_SHARED;
 			$lockTypePath2 = ILockingProvider::LOCK_SHARED;
 
 			try {
-				$exists = $this->file_exists($path2);
+				$exists = $this->file_exists($target);
 				if ($this->shouldEmitHooks()) {
 					\OC_Hook::emit(
 						Filesystem::CLASSNAME,
 						Filesystem::signal_copy,
 						[
-							Filesystem::signal_param_oldpath => $this->getHookPath($path1),
-							Filesystem::signal_param_newpath => $this->getHookPath($path2),
+							Filesystem::signal_param_oldpath => $this->getHookPath($source),
+							Filesystem::signal_param_newpath => $this->getHookPath($target),
 							Filesystem::signal_param_run => &$run
 						]
 					);
-					$this->emit_file_hooks_pre($exists, $path2, $run);
+					$this->emit_file_hooks_pre($exists, $target, $run);
 				}
 				if ($run) {
-					$mount1 = $this->getMount($path1);
-					$mount2 = $this->getMount($path2);
+					$mount1 = $this->getMount($source);
+					$mount2 = $this->getMount($target);
 					$storage1 = $mount1->getStorage();
 					$internalPath1 = $mount1->getInternalPath($absolutePath1);
 					$storage2 = $mount2->getStorage();
 					$internalPath2 = $mount2->getInternalPath($absolutePath2);
 
-					$this->changeLock($path2, ILockingProvider::LOCK_EXCLUSIVE);
+					$this->changeLock($target, ILockingProvider::LOCK_EXCLUSIVE);
 					$lockTypePath2 = ILockingProvider::LOCK_EXCLUSIVE;
 
 					if ($mount1->getMountPoint() == $mount2->getMountPoint()) {
@@ -947,7 +943,7 @@ class View {
 
 					$this->writeUpdate($storage2, $internalPath2);
 
-					$this->changeLock($path2, ILockingProvider::LOCK_SHARED);
+					$this->changeLock($target, ILockingProvider::LOCK_SHARED);
 					$lockTypePath2 = ILockingProvider::LOCK_SHARED;
 
 					if ($this->shouldEmitHooks() && $result !== false) {
@@ -955,21 +951,21 @@ class View {
 							Filesystem::CLASSNAME,
 							Filesystem::signal_post_copy,
 							[
-								Filesystem::signal_param_oldpath => $this->getHookPath($path1),
-								Filesystem::signal_param_newpath => $this->getHookPath($path2)
+								Filesystem::signal_param_oldpath => $this->getHookPath($source),
+								Filesystem::signal_param_newpath => $this->getHookPath($target)
 							]
 						);
-						$this->emit_file_hooks_post($exists, $path2);
+						$this->emit_file_hooks_post($exists, $target);
 					}
 				}
 			} catch (\Exception $e) {
-				$this->unlockFile($path2, $lockTypePath2);
-				$this->unlockFile($path1, $lockTypePath1);
+				$this->unlockFile($target, $lockTypePath2);
+				$this->unlockFile($source, $lockTypePath1);
 				throw $e;
 			}
 
-			$this->unlockFile($path2, $lockTypePath2);
-			$this->unlockFile($path1, $lockTypePath1);
+			$this->unlockFile($target, $lockTypePath2);
+			$this->unlockFile($source, $lockTypePath1);
 		}
 		return $result;
 	}
@@ -1000,11 +996,11 @@ class View {
 				$hooks[] = 'write';
 				break;
 			default:
-				\OCP\Util::writeLog('core', 'invalid mode (' . $mode . ') for ' . $path, ILogger::ERROR);
+				$this->logger->error('invalid mode (' . $mode . ') for ' . $path, ['app' => 'core']);
 		}
 
 		if ($mode !== 'r' && $mode !== 'w') {
-			\OC::$server->getLogger()->info('Trying to open a file with a mode other than "r" or "w" can cause severe performance issues with some backends');
+			$this->logger->info('Trying to open a file with a mode other than "r" or "w" can cause severe performance issues with some backends', ['app' => 'core']);
 		}
 
 		$handle = $this->basicOperation('fopen', $path, $hooks, $mode);
@@ -1051,7 +1047,6 @@ class View {
 	public function fromTmpFile($tmpFile, $path) {
 		$this->assertPathLength($path);
 		if (Filesystem::isValidPath($path)) {
-
 			// Get directory that the file is going into
 			$filePath = dirname($path);
 
@@ -1175,7 +1170,7 @@ class View {
 					try {
 						$this->changeLock($path, ILockingProvider::LOCK_EXCLUSIVE);
 					} catch (LockedException $e) {
-						// release the shared lock we acquired before quiting
+						// release the shared lock we acquired before quitting
 						$this->unlockFile($path, ILockingProvider::LOCK_SHARED);
 						throw $e;
 					}
@@ -1195,13 +1190,13 @@ class View {
 					throw $e;
 				}
 
-				if ($result && in_array('delete', $hooks)) {
+				if ($result !== false && in_array('delete', $hooks)) {
 					$this->removeUpdate($storage, $internalPath);
 				}
-				if ($result && in_array('write', $hooks, true) && $operation !== 'fopen' && $operation !== 'touch') {
+				if ($result !== false && in_array('write', $hooks, true) && $operation !== 'fopen' && $operation !== 'touch') {
 					$this->writeUpdate($storage, $internalPath);
 				}
-				if ($result && in_array('touch', $hooks)) {
+				if ($result !== false && in_array('touch', $hooks)) {
 					$this->writeUpdate($storage, $internalPath, $extraParam);
 				}
 
@@ -1246,7 +1241,7 @@ class View {
 	 * get the path relative to the default root for hook usage
 	 *
 	 * @param string $path
-	 * @return string
+	 * @return ?string
 	 */
 	private function getHookPath($path) {
 		if (!Filesystem::getView()) {
@@ -1330,7 +1325,7 @@ class View {
 	 * @return IUser
 	 */
 	private function getUserObjectForOwner(string $ownerId) {
-		return new LazyUser($ownerId, $this->displayNameCache, $this->userManager);
+		return new LazyUser($ownerId, $this->userManager);
 	}
 
 	/**
@@ -1377,9 +1372,8 @@ class View {
 	 * get the filesystem info
 	 *
 	 * @param string $path
-	 * @param boolean|string $includeMountPoints true to add mountpoint sizes,
+	 * @param bool|string $includeMountPoints true to add mountpoint sizes,
 	 * 'ext' to add only ext storage mount point sizes. Defaults to true.
-	 * defaults to true
 	 * @return \OC\Files\FileInfo|false False if file does not exist
 	 */
 	public function getFileInfo($path, $includeMountPoints = true) {
@@ -1418,22 +1412,29 @@ class View {
 				if ($includeMountPoints and $data['mimetype'] === 'httpd/unix-directory') {
 					//add the sizes of other mount points to the folder
 					$extOnly = ($includeMountPoints === 'ext');
-					$mounts = Filesystem::getMountManager()->findIn($path);
-					$info->setSubMounts(array_filter($mounts, function (IMountPoint $mount) use ($extOnly) {
-						$subStorage = $mount->getStorage();
-						return !($extOnly && $subStorage instanceof \OCA\Files_Sharing\SharedStorage);
-					}));
+					$this->addSubMounts($info, $extOnly);
 				}
 			}
 
 			return $info;
 		} else {
-			\OC::$server->getLogger()->warning('Storage not valid for mountpoint: ' . $mount->getMountPoint());
+			$this->logger->warning('Storage not valid for mountpoint: ' . $mount->getMountPoint(), ['app' => 'core']);
 		}
 
 		return false;
 	}
 
+	/**
+	 * Extend a FileInfo that was previously requested with `$includeMountPoints = false` to include the sub mounts
+	 */
+	public function addSubMounts(FileInfo $info, $extOnly = false): void {
+		$mounts = Filesystem::getMountManager()->findIn($info->getPath());
+		$info->setSubMounts(array_filter($mounts, function (IMountPoint $mount) use ($extOnly) {
+			$subStorage = $mount->getStorage();
+			return !($extOnly && $subStorage instanceof \OCA\Files_Sharing\SharedStorage);
+		}));
+	}
+
 	/**
 	 * get the content of a directory
 	 *
@@ -1512,10 +1513,9 @@ class View {
 						continue;
 					} catch (\Exception $e) {
 						// sometimes when the storage is not available it can be any exception
-						\OC::$server->getLogger()->logException($e, [
-							'message' => 'Exception while scanning storage "' . $subStorage->getId() . '"',
-							'level' => ILogger::ERROR,
-							'app' => 'lib',
+						$this->logger->error('Exception while scanning storage "' . $subStorage->getId() . '"', [
+							'exception' => $e,
+							'app' => 'core',
 						]);
 						continue;
 					}
@@ -1737,7 +1737,7 @@ class View {
 	/**
 	 * Get the path of a file by id, relative to the view
 	 *
-	 * Note that the resulting path is not guarantied to be unique for the id, multiple paths can point to the same file
+	 * Note that the resulting path is not guaranteed to be unique for the id, multiple paths can point to the same file
 	 *
 	 * @param int $id
 	 * @param int|null $storageId
@@ -1808,7 +1808,6 @@ class View {
 	 * @return boolean
 	 */
 	private function targetIsNotShared(IStorage $targetStorage, string $targetInternalPath) {
-
 		// note: cannot use the view because the target is already locked
 		$fileId = (int)$targetStorage->getCache()->getId($targetInternalPath);
 		if ($fileId === -1) {
@@ -1817,18 +1816,18 @@ class View {
 		}
 
 		// check if any of the parents were shared by the current owner (include collections)
-		$shares = \OCP\Share::getItemShared(
+		$shares = Share::getItemShared(
 			'folder',
 			$fileId,
-			\OCP\Share::FORMAT_NONE,
+			\OC\Share\Constants::FORMAT_NONE,
 			null,
 			true
 		);
 
 		if (count($shares) > 0) {
-			\OCP\Util::writeLog('files',
+			$this->logger->debug(
 				'It is not allowed to move one mount point into a shared folder',
-				ILogger::DEBUG);
+				['app' => 'files']);
 			return false;
 		}
 
@@ -2156,9 +2155,9 @@ class View {
 		// "$user", "files", "path/to/dir"
 		if (!isset($parts[1]) || $parts[1] !== 'files') {
 			$this->logger->error(
-				'$absolutePath must be relative to "files", value is "%s"',
+				'$absolutePath must be relative to "files", value is "{absolutePath}"',
 				[
-					$absolutePath
+					'absolutePath' => $absolutePath,
 				]
 			);
 			throw new \InvalidArgumentException('$absolutePath must be relative to "files"');
