@@ -1,12 +1,19 @@
 <?php
+
+declare(strict_types=1);
+
 /**
  * @copyright Copyright (c) 2016, ownCloud, Inc.
  * @copyright Copyright (c) 2016, Lukas Reschke <lukas@statuscode.ch>
  *
  * @author Arthur Schiwon <blizzz@arthur-schiwon.de>
  * @author Bjoern Schiessle <bjoern@schiessle.org>
+ * @author Christoph Wurst <christoph@winzerhof-wurst.at>
  * @author Frank Karlitschek <frank@karlitschek.de>
+ * @author Georg Ehrke <oc.list@georgehrke.com>
+ * @author J0WI <J0WI@users.noreply.github.com>
  * @author Joas Schilling <coding@schilljs.com>
+ * @author Julius Härtl <jus@bitgrid.net>
  * @author Lukas Reschke <lukas@statuscode.ch>
  * @author Morris Jobke <hey@morrisjobke.de>
  * @author Robin Appelman <robin@icewind.nl>
@@ -14,7 +21,7 @@
  * @author Steffen Lindner <mail@steffen-lindner.de>
  * @author Thomas Müller <thomas.mueller@tmit.eu>
  * @author Victor Dubiniuk <dubiniuk@owncloud.com>
- * @author Vincent Petry <pvince81@owncloud.com>
+ * @author Vincent Petry <vincent@nextcloud.com>
  *
  * @license AGPL-3.0
  *
@@ -28,20 +35,33 @@
  * GNU Affero General Public License for more details.
  *
  * You should have received a copy of the GNU Affero General Public License, version 3,
- * along with this program.  If not, see <http://www.gnu.org/licenses/>
+ * along with this program. If not, see <http://www.gnu.org/licenses/>
  *
  */
-
 namespace OC;
 
-use OC\DB\MigrationService;
-use OC\Hooks\BasicEmitter;
-use OC\IntegrityCheck\Checker;
-use OC_App;
+use OCP\App\IAppManager;
+use OCP\EventDispatcher\Event;
+use OCP\EventDispatcher\IEventDispatcher;
+use OCP\HintException;
 use OCP\IConfig;
 use OCP\ILogger;
 use OCP\Util;
-use Symfony\Component\EventDispatcher\GenericEvent;
+use OC\App\AppManager;
+use OC\DB\Connection;
+use OC\DB\MigrationService;
+use OC\DB\MigratorExecuteSqlEvent;
+use OC\Hooks\BasicEmitter;
+use OC\IntegrityCheck\Checker;
+use OC\Repair\Events\RepairAdvanceEvent;
+use OC\Repair\Events\RepairErrorEvent;
+use OC\Repair\Events\RepairFinishEvent;
+use OC\Repair\Events\RepairInfoEvent;
+use OC\Repair\Events\RepairStartEvent;
+use OC\Repair\Events\RepairStepEvent;
+use OC\Repair\Events\RepairWarningEvent;
+use OC_App;
+use Psr\Log\LoggerInterface;
 
 /**
  * Class that handles autoupdating of ownCloud
@@ -53,8 +73,7 @@ use Symfony\Component\EventDispatcher\GenericEvent;
  *  - failure(string $message)
  */
 class Updater extends BasicEmitter {
-
-	/** @var ILogger $log */
+	/** @var LoggerInterface */
 	private $log;
 
 	/** @var IConfig */
@@ -74,15 +93,9 @@ class Updater extends BasicEmitter {
 		4 => 'Fatal',
 	];
 
-	/**
-	 * @param IConfig $config
-	 * @param Checker $checker
-	 * @param ILogger $log
-	 * @param Installer $installer
-	 */
 	public function __construct(IConfig $config,
 								Checker $checker,
-								ILogger $log = null,
+								?LoggerInterface $log,
 								Installer $installer) {
 		$this->log = $log;
 		$this->config = $config;
@@ -96,17 +109,16 @@ class Updater extends BasicEmitter {
 	 *
 	 * @return bool true if the operation succeeded, false otherwise
 	 */
-	public function upgrade() {
-		$this->emitRepairEvents();
+	public function upgrade(): bool {
 		$this->logAllEvents();
 
 		$logLevel = $this->config->getSystemValue('loglevel', ILogger::WARN);
 		$this->emit('\OC\Updater', 'setDebugLogLevel', [ $logLevel, $this->logLevelNames[$logLevel] ]);
 		$this->config->setSystemValue('loglevel', ILogger::DEBUG);
 
-		$wasMaintenanceModeEnabled = $this->config->getSystemValue('maintenance', false);
+		$wasMaintenanceModeEnabled = $this->config->getSystemValueBool('maintenance');
 
-		if(!$wasMaintenanceModeEnabled) {
+		if (!$wasMaintenanceModeEnabled) {
 			$this->config->setSystemValue('maintenance', true);
 			$this->emit('\OC\Updater', 'maintenanceEnabled');
 		}
@@ -121,24 +133,28 @@ class Updater extends BasicEmitter {
 		$installedVersion = $this->config->getSystemValue('version', '0.0.0');
 		$currentVersion = implode('.', \OCP\Util::getVersion());
 
-		$this->log->debug('starting upgrade from ' . $installedVersion . ' to ' . $currentVersion, array('app' => 'core'));
+		$this->log->debug('starting upgrade from ' . $installedVersion . ' to ' . $currentVersion, ['app' => 'core']);
 
 		$success = true;
 		try {
 			$this->doUpgrade($currentVersion, $installedVersion);
 		} catch (HintException $exception) {
-			$this->log->logException($exception, ['app' => 'core']);
-			$this->emit('\OC\Updater', 'failure', array($exception->getMessage() . ': ' .$exception->getHint()));
+			$this->log->error($exception->getMessage(), [
+				'exception' => $exception,
+			]);
+			$this->emit('\OC\Updater', 'failure', [$exception->getMessage() . ': ' .$exception->getHint()]);
 			$success = false;
 		} catch (\Exception $exception) {
-			$this->log->logException($exception, ['app' => 'core']);
-			$this->emit('\OC\Updater', 'failure', array(get_class($exception) . ': ' .$exception->getMessage()));
+			$this->log->error($exception->getMessage(), [
+				'exception' => $exception,
+			]);
+			$this->emit('\OC\Updater', 'failure', [get_class($exception) . ': ' .$exception->getMessage()]);
 			$success = false;
 		}
 
-		$this->emit('\OC\Updater', 'updateEnd', array($success));
+		$this->emit('\OC\Updater', 'updateEnd', [$success]);
 
-		if(!$wasMaintenanceModeEnabled && $success) {
+		if (!$wasMaintenanceModeEnabled && $success) {
 			$this->config->setSystemValue('maintenance', false);
 			$this->emit('\OC\Updater', 'maintenanceDisabled');
 		} else {
@@ -157,7 +173,7 @@ class Updater extends BasicEmitter {
 	 *
 	 * @return array allowed previous versions per vendor
 	 */
-	private function getAllowedPreviousVersions() {
+	private function getAllowedPreviousVersions(): array {
 		// this should really be a JSON file
 		require \OC::$SERVERROOT . '/version.php';
 		/** @var array $OC_VersionCanBeUpgradedFrom */
@@ -169,7 +185,7 @@ class Updater extends BasicEmitter {
 	 *
 	 * @return string Get the vendor
 	 */
-	private function getVendor() {
+	private function getVendor(): string {
 		// this should really be a JSON file
 		require \OC::$SERVERROOT . '/version.php';
 		/** @var string $vendor */
@@ -183,15 +199,19 @@ class Updater extends BasicEmitter {
 	 * @param array $allowedPreviousVersions
 	 * @return bool
 	 */
-	public function isUpgradePossible($oldVersion, $newVersion, array $allowedPreviousVersions) {
+	public function isUpgradePossible(string $oldVersion, string $newVersion, array $allowedPreviousVersions): bool {
 		$version = explode('.', $oldVersion);
 		$majorMinor = $version[0] . '.' . $version[1];
 
 		$currentVendor = $this->config->getAppValue('core', 'vendor', '');
 
 		// Vendor was not set correctly on install, so we have to white-list known versions
-		if ($currentVendor === '' && isset($allowedPreviousVersions['owncloud'][$oldVersion])) {
+		if ($currentVendor === '' && (
+			isset($allowedPreviousVersions['owncloud'][$oldVersion]) ||
+			isset($allowedPreviousVersions['owncloud'][$majorMinor])
+		)) {
 			$currentVendor = 'owncloud';
+			$this->config->setAppValue('core', 'vendor', $currentVendor);
 		}
 
 		if ($currentVendor === 'nextcloud') {
@@ -214,7 +234,7 @@ class Updater extends BasicEmitter {
 	 *
 	 * @throws \Exception
 	 */
-	private function doUpgrade($currentVersion, $installedVersion) {
+	private function doUpgrade(string $currentVersion, string $installedVersion): void {
 		// Stop update if the update is over several major versions
 		$allowedPreviousVersions = $this->getAllowedPreviousVersions();
 		if (!$this->isUpgradePossible($installedVersion, $currentVersion, $allowedPreviousVersions)) {
@@ -235,7 +255,7 @@ class Updater extends BasicEmitter {
 		file_put_contents($this->config->getSystemValue('datadirectory', \OC::$SERVERROOT . '/data') . '/.ocdata', '');
 
 		// pre-upgrade repairs
-		$repair = new Repair(Repair::getBeforeUpgradeRepairSteps(), \OC::$server->getEventDispatcher());
+		$repair = new Repair(Repair::getBeforeUpgradeRepairSteps(), \OC::$server->get(\OCP\EventDispatcher\IEventDispatcher::class), \OC::$server->get(LoggerInterface::class));
 		$repair->run();
 
 		$this->doCoreUpgrade();
@@ -254,28 +274,36 @@ class Updater extends BasicEmitter {
 		// Update the appfetchers version so it downloads the correct list from the appstore
 		\OC::$server->getAppFetcher()->setVersion($currentVersion);
 
+		/** @var IAppManager|AppManager $appManager */
+		$appManager = \OC::$server->getAppManager();
+
 		// upgrade appstore apps
-		$this->upgradeAppStoreApps(\OC::$server->getAppManager()->getInstalledApps());
-		$this->upgradeAppStoreApps(\OC_App::$autoDisabledApps, true);
+		$this->upgradeAppStoreApps($appManager->getInstalledApps());
+		$autoDisabledApps = $appManager->getAutoDisabledApps();
+		if (!empty($autoDisabledApps)) {
+			$this->upgradeAppStoreApps(array_keys($autoDisabledApps), $autoDisabledApps);
+		}
 
 		// install new shipped apps on upgrade
-		OC_App::loadApps(['authentication']);
 		$errors = Installer::installShippedApps(true);
 		foreach ($errors as $appId => $exception) {
 			/** @var \Exception $exception */
-			$this->log->logException($exception, ['app' => $appId]);
+			$this->log->error($exception->getMessage(), [
+				'exception' => $exception,
+				'app' => $appId,
+			]);
 			$this->emit('\OC\Updater', 'failure', [$appId . ': ' . $exception->getMessage()]);
 		}
 
 		// post-upgrade repairs
-		$repair = new Repair(Repair::getRepairSteps(), \OC::$server->getEventDispatcher());
+		$repair = new Repair(Repair::getRepairSteps(), \OC::$server->get(\OCP\EventDispatcher\IEventDispatcher::class), \OC::$server->get(LoggerInterface::class));
 		$repair->run();
 
 		//Invalidate update feed
-		$this->config->setAppValue('core', 'lastupdatedat', 0);
+		$this->config->setAppValue('core', 'lastupdatedat', '0');
 
 		// Check for code integrity if not disabled
-		if(\OC::$server->getIntegrityCodeChecker()->isCodeCheckEnforced()) {
+		if (\OC::$server->getIntegrityCodeChecker()->isCodeCheckEnforced()) {
 			$this->emit('\OC\Updater', 'startCheckCodeIntegrity');
 			$this->checker->runInstanceVerification();
 			$this->emit('\OC\Updater', 'finishedCheckCodeIntegrity');
@@ -286,74 +314,33 @@ class Updater extends BasicEmitter {
 		$this->config->setAppValue('core', 'vendor', $this->getVendor());
 	}
 
-	protected function doCoreUpgrade() {
+	protected function doCoreUpgrade(): void {
 		$this->emit('\OC\Updater', 'dbUpgradeBefore');
 
 		// execute core migrations
-		$ms = new MigrationService('core', \OC::$server->getDatabaseConnection());
+		$ms = new MigrationService('core', \OC::$server->get(Connection::class));
 		$ms->migrate();
 
 		$this->emit('\OC\Updater', 'dbUpgrade');
 	}
 
-	/**
-	 * @param string $version the oc version to check app compatibility with
-	 */
-	protected function checkAppUpgrade($version) {
-		$apps = \OC_App::getEnabledApps();
-		$this->emit('\OC\Updater', 'appUpgradeCheckBefore');
-
-		$appManager = \OC::$server->getAppManager();
-		foreach ($apps as $appId) {
-			$info = \OC_App::getAppInfo($appId);
-			$compatible = \OC_App::isAppCompatible($version, $info);
-			$isShipped = $appManager->isShipped($appId);
-
-			if ($compatible && $isShipped && \OC_App::shouldUpgrade($appId)) {
-				/**
-				 * FIXME: The preupdate check is performed before the database migration, otherwise database changes
-				 * are not possible anymore within it. - Consider this when touching the code.
-				 * @link https://github.com/owncloud/core/issues/10980
-				 * @see \OC_App::updateApp
-				 */
-				if (file_exists(\OC_App::getAppPath($appId) . '/appinfo/preupdate.php')) {
-					$this->includePreUpdate($appId);
-				}
-				if (file_exists(\OC_App::getAppPath($appId) . '/appinfo/database.xml')) {
-					$this->emit('\OC\Updater', 'appSimulateUpdate', array($appId));
-					\OC_DB::simulateUpdateDbFromStructure(\OC_App::getAppPath($appId) . '/appinfo/database.xml');
-				}
-			}
-		}
-
-		$this->emit('\OC\Updater', 'appUpgradeCheck');
-	}
-
-	/**
-	 * Includes the pre-update file. Done here to prevent namespace mixups.
-	 * @param string $appId
-	 */
-	private function includePreUpdate($appId) {
-		include \OC_App::getAppPath($appId) . '/appinfo/preupdate.php';
-	}
-
 	/**
 	 * upgrades all apps within a major ownCloud upgrade. Also loads "priority"
 	 * (types authentication, filesystem, logging, in that order) afterwards.
 	 *
 	 * @throws NeedsUpdateException
 	 */
-	protected function doAppUpgrade() {
+	protected function doAppUpgrade(): void {
 		$apps = \OC_App::getEnabledApps();
-		$priorityTypes = array('authentication', 'filesystem', 'logging');
+		$priorityTypes = ['authentication', 'filesystem', 'logging'];
 		$pseudoOtherType = 'other';
-		$stacks = array($pseudoOtherType => array());
+		$stacks = [$pseudoOtherType => []];
 
 		foreach ($apps as $appId) {
 			$priorityType = false;
 			foreach ($priorityTypes as $type) {
-				if(!isset($stacks[$type])) {
-					$stacks[$type] = array();
+				if (!isset($stacks[$type])) {
+					$stacks[$type] = [];
 				}
 				if (\OC_App::isType($appId, [$type])) {
 					$stacks[$type][] = $appId;
@@ -365,14 +352,15 @@ class Updater extends BasicEmitter {
 				$stacks[$pseudoOtherType][] = $appId;
 			}
 		}
-		foreach ($stacks as $type => $stack) {
+		foreach (array_merge($priorityTypes, [$pseudoOtherType]) as $type) {
+			$stack = $stacks[$type];
 			foreach ($stack as $appId) {
 				if (\OC_App::shouldUpgrade($appId)) {
 					$this->emit('\OC\Updater', 'appUpgradeStarted', [$appId, \OC_App::getAppVersion($appId)]);
 					\OC_App::updateApp($appId);
 					$this->emit('\OC\Updater', 'appUpgrade', [$appId, \OC_App::getAppVersion($appId)]);
 				}
-				if($type !== $pseudoOtherType) {
+				if ($type !== $pseudoOtherType) {
 					// load authentication, filesystem and logging apps after
 					// upgrading them. Other apps my need to rely on modifying
 					// user and/or filesystem aspects.
@@ -388,45 +376,30 @@ class Updater extends BasicEmitter {
 	 * This is important if you upgrade ownCloud and have non ported 3rd
 	 * party apps installed.
 	 *
-	 * @return array
 	 * @throws \Exception
 	 */
-	private function checkAppsRequirements() {
+	private function checkAppsRequirements(): void {
 		$isCoreUpgrade = $this->isCodeUpgrade();
 		$apps = OC_App::getEnabledApps();
 		$version = implode('.', Util::getVersion());
-		$disabledApps = [];
 		$appManager = \OC::$server->getAppManager();
 		foreach ($apps as $app) {
-			// check if the app is compatible with this version of ownCloud
-			$info = OC_App::getAppInfo($app);
-			if($info === null || !OC_App::isAppCompatible($version, $info)) {
+			// check if the app is compatible with this version of Nextcloud
+			$info = $appManager->getAppInfo($app);
+			if ($info === null || !OC_App::isAppCompatible($version, $info)) {
 				if ($appManager->isShipped($app)) {
 					throw new \UnexpectedValueException('The files of the app "' . $app . '" were not correctly replaced before running the update');
 				}
-				\OC::$server->getAppManager()->disableApp($app);
-				$this->emit('\OC\Updater', 'incompatibleAppDisabled', array($app));
-			}
-			// no need to disable any app in case this is a non-core upgrade
-			if (!$isCoreUpgrade) {
-				continue;
-			}
-			// shipped apps will remain enabled
-			if ($appManager->isShipped($app)) {
-				continue;
-			}
-			// authentication and session apps will remain enabled as well
-			if (OC_App::isType($app, ['session', 'authentication'])) {
-				continue;
+				$appManager->disableApp($app, true);
+				$this->emit('\OC\Updater', 'incompatibleAppDisabled', [$app]);
 			}
 		}
-		return $disabledApps;
 	}
 
 	/**
 	 * @return bool
 	 */
-	private function isCodeUpgrade() {
+	private function isCodeUpgrade(): bool {
 		$installedVersion = $this->config->getSystemValue('version', '0.0.0');
 		$currentVersion = implode('.', Util::getVersion());
 		if (version_compare($currentVersion, $installedVersion, '>')) {
@@ -436,12 +409,12 @@ class Updater extends BasicEmitter {
 	}
 
 	/**
-	 * @param array $disabledApps
-	 * @param bool $reenable
+	 * @param array $apps
+	 * @param array $previousEnableStates
 	 * @throws \Exception
 	 */
-	private function upgradeAppStoreApps(array $disabledApps, $reenable = false) {
-		foreach($disabledApps as $app) {
+	private function upgradeAppStoreApps(array $apps, array $previousEnableStates = []): void {
+		foreach ($apps as $app) {
 			try {
 				$this->emit('\OC\Updater', 'checkAppStoreAppBefore', [$app]);
 				if ($this->installer->isUpdateAvailable($app)) {
@@ -450,175 +423,122 @@ class Updater extends BasicEmitter {
 				}
 				$this->emit('\OC\Updater', 'checkAppStoreApp', [$app]);
 
-				if ($reenable) {
+				if (!empty($previousEnableStates)) {
 					$ocApp = new \OC_App();
-					$ocApp->enable($app);
+					if (!empty($previousEnableStates[$app]) && is_array($previousEnableStates[$app])) {
+						$ocApp->enable($app, $previousEnableStates[$app]);
+					} else {
+						$ocApp->enable($app);
+					}
 				}
 			} catch (\Exception $ex) {
-				$this->log->logException($ex, ['app' => 'core']);
+				$this->log->error($ex->getMessage(), [
+					'exception' => $ex,
+				]);
 			}
 		}
 	}
 
-	/**
-	 * Forward messages emitted by the repair routine
-	 */
-	private function emitRepairEvents() {
-		$dispatcher = \OC::$server->getEventDispatcher();
-		$dispatcher->addListener('\OC\Repair::warning', function ($event) {
-			if ($event instanceof GenericEvent) {
-				$this->emit('\OC\Updater', 'repairWarning', $event->getArguments());
-			}
-		});
-		$dispatcher->addListener('\OC\Repair::error', function ($event) {
-			if ($event instanceof GenericEvent) {
-				$this->emit('\OC\Updater', 'repairError', $event->getArguments());
-			}
-		});
-		$dispatcher->addListener('\OC\Repair::info', function ($event) {
-			if ($event instanceof GenericEvent) {
-				$this->emit('\OC\Updater', 'repairInfo', $event->getArguments());
-			}
-		});
-		$dispatcher->addListener('\OC\Repair::step', function ($event) {
-			if ($event instanceof GenericEvent) {
-				$this->emit('\OC\Updater', 'repairStep', $event->getArguments());
-			}
-		});
-	}
-
-	private function logAllEvents() {
+	private function logAllEvents(): void {
 		$log = $this->log;
 
-		$dispatcher = \OC::$server->getEventDispatcher();
-		$dispatcher->addListener('\OC\DB\Migrator::executeSql', function($event) use ($log) {
-			if (!$event instanceof GenericEvent) {
-				return;
+		/** @var IEventDispatcher $dispatcher */
+		$dispatcher = \OC::$server->get(IEventDispatcher::class);
+		$dispatcher->addListener(
+			MigratorExecuteSqlEvent::class,
+			function (MigratorExecuteSqlEvent $event) use ($log): void {
+				$log->info(get_class($event).': ' . $event->getSql() . ' (' . $event->getCurrentStep() . ' of ' . $event->getMaxStep() . ')', ['app' => 'updater']);
 			}
-			$log->info('\OC\DB\Migrator::executeSql: ' . $event->getSubject() . ' (' . $event->getArgument(0) . ' of ' . $event->getArgument(1) . ')', ['app' => 'updater']);
-		});
-		$dispatcher->addListener('\OC\DB\Migrator::checkTable', function($event) use ($log) {
-			if (!$event instanceof GenericEvent) {
-				return;
-			}
-			$log->info('\OC\DB\Migrator::checkTable: ' . $event->getSubject() . ' (' . $event->getArgument(0) . ' of ' . $event->getArgument(1) . ')', ['app' => 'updater']);
-		});
+		);
 
-		$repairListener = function($event) use ($log) {
-			if (!$event instanceof GenericEvent) {
-				return;
-			}
-			switch ($event->getSubject()) {
-				case '\OC\Repair::startProgress':
-					$log->info('\OC\Repair::startProgress: Starting ... ' . $event->getArgument(1) .  ' (' . $event->getArgument(0) . ')', ['app' => 'updater']);
-					break;
-				case '\OC\Repair::advance':
-					$desc = $event->getArgument(1);
-					if (empty($desc)) {
-						$desc = '';
-					}
-					$log->info('\OC\Repair::advance: ' . $desc . ' (' . $event->getArgument(0) . ')', ['app' => 'updater']);
-
-					break;
-				case '\OC\Repair::finishProgress':
-					$log->info('\OC\Repair::finishProgress', ['app' => 'updater']);
-					break;
-				case '\OC\Repair::step':
-					$log->info('\OC\Repair::step: Repair step: ' . $event->getArgument(0), ['app' => 'updater']);
-					break;
-				case '\OC\Repair::info':
-					$log->info('\OC\Repair::info: Repair info: ' . $event->getArgument(0), ['app' => 'updater']);
-					break;
-				case '\OC\Repair::warning':
-					$log->warning('\OC\Repair::warning: Repair warning: ' . $event->getArgument(0), ['app' => 'updater']);
-					break;
-				case '\OC\Repair::error':
-					$log->error('\OC\Repair::error: Repair error: ' . $event->getArgument(0), ['app' => 'updater']);
-					break;
+		$repairListener = function (Event $event) use ($log): void {
+			if ($event instanceof RepairStartEvent) {
+				$log->info(get_class($event).': Starting ... ' . $event->getMaxStep() .  ' (' . $event->getCurrentStepName() . ')', ['app' => 'updater']);
+			} elseif ($event instanceof RepairAdvanceEvent) {
+				$desc = $event->getDescription();
+				if (empty($desc)) {
+					$desc = '';
+				}
+				$log->info(get_class($event).': ' . $desc . ' (' . $event->getIncrement() . ')', ['app' => 'updater']);
+			} elseif ($event instanceof RepairFinishEvent) {
+				$log->info(get_class($event), ['app' => 'updater']);
+			} elseif ($event instanceof RepairStepEvent) {
+				$log->info(get_class($event).': Repair step: ' . $event->getStepName(), ['app' => 'updater']);
+			} elseif ($event instanceof RepairInfoEvent) {
+				$log->info(get_class($event).': Repair info: ' . $event->getMessage(), ['app' => 'updater']);
+			} elseif ($event instanceof RepairWarningEvent) {
+				$log->warning(get_class($event).': Repair warning: ' . $event->getMessage(), ['app' => 'updater']);
+			} elseif ($event instanceof RepairErrorEvent) {
+				$log->error(get_class($event).': Repair error: ' . $event->getMessage(), ['app' => 'updater']);
 			}
 		};
 
-		$dispatcher->addListener('\OC\Repair::startProgress', $repairListener);
-		$dispatcher->addListener('\OC\Repair::advance', $repairListener);
-		$dispatcher->addListener('\OC\Repair::finishProgress', $repairListener);
-		$dispatcher->addListener('\OC\Repair::step', $repairListener);
-		$dispatcher->addListener('\OC\Repair::info', $repairListener);
-		$dispatcher->addListener('\OC\Repair::warning', $repairListener);
-		$dispatcher->addListener('\OC\Repair::error', $repairListener);
+		$dispatcher->addListener(RepairStartEvent::class, $repairListener);
+		$dispatcher->addListener(RepairAdvanceEvent::class, $repairListener);
+		$dispatcher->addListener(RepairFinishEvent::class, $repairListener);
+		$dispatcher->addListener(RepairStepEvent::class, $repairListener);
+		$dispatcher->addListener(RepairInfoEvent::class, $repairListener);
+		$dispatcher->addListener(RepairWarningEvent::class, $repairListener);
+		$dispatcher->addListener(RepairErrorEvent::class, $repairListener);
 
 
-		$this->listen('\OC\Updater', 'maintenanceEnabled', function () use($log) {
+		$this->listen('\OC\Updater', 'maintenanceEnabled', function () use ($log) {
 			$log->info('\OC\Updater::maintenanceEnabled: Turned on maintenance mode', ['app' => 'updater']);
 		});
-		$this->listen('\OC\Updater', 'maintenanceDisabled', function () use($log) {
+		$this->listen('\OC\Updater', 'maintenanceDisabled', function () use ($log) {
 			$log->info('\OC\Updater::maintenanceDisabled: Turned off maintenance mode', ['app' => 'updater']);
 		});
-		$this->listen('\OC\Updater', 'maintenanceActive', function () use($log) {
+		$this->listen('\OC\Updater', 'maintenanceActive', function () use ($log) {
 			$log->info('\OC\Updater::maintenanceActive: Maintenance mode is kept active', ['app' => 'updater']);
 		});
-		$this->listen('\OC\Updater', 'updateEnd', function ($success) use($log) {
+		$this->listen('\OC\Updater', 'updateEnd', function ($success) use ($log) {
 			if ($success) {
 				$log->info('\OC\Updater::updateEnd: Update successful', ['app' => 'updater']);
 			} else {
 				$log->error('\OC\Updater::updateEnd: Update failed', ['app' => 'updater']);
 			}
 		});
-		$this->listen('\OC\Updater', 'dbUpgradeBefore', function () use($log) {
+		$this->listen('\OC\Updater', 'dbUpgradeBefore', function () use ($log) {
 			$log->info('\OC\Updater::dbUpgradeBefore: Updating database schema', ['app' => 'updater']);
 		});
-		$this->listen('\OC\Updater', 'dbUpgrade', function () use($log) {
+		$this->listen('\OC\Updater', 'dbUpgrade', function () use ($log) {
 			$log->info('\OC\Updater::dbUpgrade: Updated database', ['app' => 'updater']);
 		});
-		$this->listen('\OC\Updater', 'dbSimulateUpgradeBefore', function () use($log) {
-			$log->info('\OC\Updater::dbSimulateUpgradeBefore: Checking whether the database schema can be updated (this can take a long time depending on the database size)', ['app' => 'updater']);
-		});
-		$this->listen('\OC\Updater', 'dbSimulateUpgrade', function () use($log) {
-			$log->info('\OC\Updater::dbSimulateUpgrade: Checked database schema update', ['app' => 'updater']);
-		});
-		$this->listen('\OC\Updater', 'incompatibleAppDisabled', function ($app) use($log) {
+		$this->listen('\OC\Updater', 'incompatibleAppDisabled', function ($app) use ($log) {
 			$log->info('\OC\Updater::incompatibleAppDisabled: Disabled incompatible app: ' . $app, ['app' => 'updater']);
 		});
-		$this->listen('\OC\Updater', 'checkAppStoreAppBefore', function ($app) use($log) {
-			$log->info('\OC\Updater::checkAppStoreAppBefore: Checking for update of app "' . $app . '" in appstore', ['app' => 'updater']);
+		$this->listen('\OC\Updater', 'checkAppStoreAppBefore', function ($app) use ($log) {
+			$log->debug('\OC\Updater::checkAppStoreAppBefore: Checking for update of app "' . $app . '" in appstore', ['app' => 'updater']);
 		});
-		$this->listen('\OC\Updater', 'upgradeAppStoreApp', function ($app) use($log) {
+		$this->listen('\OC\Updater', 'upgradeAppStoreApp', function ($app) use ($log) {
 			$log->info('\OC\Updater::upgradeAppStoreApp: Update app "' . $app . '" from appstore', ['app' => 'updater']);
 		});
-		$this->listen('\OC\Updater', 'checkAppStoreApp', function ($app) use($log) {
-			$log->info('\OC\Updater::checkAppStoreApp: Checked for update of app "' . $app . '" in appstore', ['app' => 'updater']);
-		});
-		$this->listen('\OC\Updater', 'appUpgradeCheckBefore', function () use ($log) {
-			$log->info('\OC\Updater::appUpgradeCheckBefore: Checking updates of apps', ['app' => 'updater']);
+		$this->listen('\OC\Updater', 'checkAppStoreApp', function ($app) use ($log) {
+			$log->debug('\OC\Updater::checkAppStoreApp: Checked for update of app "' . $app . '" in appstore', ['app' => 'updater']);
 		});
 		$this->listen('\OC\Updater', 'appSimulateUpdate', function ($app) use ($log) {
 			$log->info('\OC\Updater::appSimulateUpdate: Checking whether the database schema for <' . $app . '> can be updated (this can take a long time depending on the database size)', ['app' => 'updater']);
 		});
-		$this->listen('\OC\Updater', 'appUpgradeCheck', function () use ($log) {
-			$log->info('\OC\Updater::appUpgradeCheck: Checked database schema update for apps', ['app' => 'updater']);
-		});
 		$this->listen('\OC\Updater', 'appUpgradeStarted', function ($app) use ($log) {
 			$log->info('\OC\Updater::appUpgradeStarted: Updating <' . $app . '> ...', ['app' => 'updater']);
 		});
 		$this->listen('\OC\Updater', 'appUpgrade', function ($app, $version) use ($log) {
 			$log->info('\OC\Updater::appUpgrade: Updated <' . $app . '> to ' . $version, ['app' => 'updater']);
 		});
-		$this->listen('\OC\Updater', 'failure', function ($message) use($log) {
+		$this->listen('\OC\Updater', 'failure', function ($message) use ($log) {
 			$log->error('\OC\Updater::failure: ' . $message, ['app' => 'updater']);
 		});
-		$this->listen('\OC\Updater', 'setDebugLogLevel', function () use($log) {
+		$this->listen('\OC\Updater', 'setDebugLogLevel', function () use ($log) {
 			$log->info('\OC\Updater::setDebugLogLevel: Set log level to debug', ['app' => 'updater']);
 		});
-		$this->listen('\OC\Updater', 'resetLogLevel', function ($logLevel, $logLevelName) use($log) {
+		$this->listen('\OC\Updater', 'resetLogLevel', function ($logLevel, $logLevelName) use ($log) {
 			$log->info('\OC\Updater::resetLogLevel: Reset log level to ' . $logLevelName . '(' . $logLevel . ')', ['app' => 'updater']);
 		});
-		$this->listen('\OC\Updater', 'startCheckCodeIntegrity', function () use($log) {
+		$this->listen('\OC\Updater', 'startCheckCodeIntegrity', function () use ($log) {
 			$log->info('\OC\Updater::startCheckCodeIntegrity: Starting code integrity check...', ['app' => 'updater']);
 		});
-		$this->listen('\OC\Updater', 'finishedCheckCodeIntegrity', function () use($log) {
+		$this->listen('\OC\Updater', 'finishedCheckCodeIntegrity', function () use ($log) {
 			$log->info('\OC\Updater::finishedCheckCodeIntegrity: Finished code integrity check', ['app' => 'updater']);
 		});
-
 	}
-
 }
-
