@@ -3,6 +3,8 @@
  * @copyright Copyright (c) 2016, ownCloud, Inc.
  *
  * @author Bernhard Posselt <dev@bernhard-posselt.com>
+ * @author Christoph Wurst <christoph@winzerhof-wurst.at>
+ * @author Julius Härtl <jus@bitgrid.net>
  * @author Morris Jobke <hey@morrisjobke.de>
  *
  * @license AGPL-3.0
@@ -17,30 +19,40 @@
  * GNU Affero General Public License for more details.
  *
  * You should have received a copy of the GNU Affero General Public License, version 3,
- * along with this program.  If not, see <http://www.gnu.org/licenses/>
+ * along with this program. If not, see <http://www.gnu.org/licenses/>
  *
  */
-
-
 namespace OCP\Files;
 
 use OC\Hooks\Emitter;
+use OC\User\NoUserException;
 
 /**
  * Interface IRootFolder
  *
- * @package OCP\Files
  * @since 8.0.0
  */
 interface IRootFolder extends Folder, Emitter {
-
 	/**
 	 * Returns a view to user's files folder
 	 *
 	 * @param string $userId user ID
-	 * @return \OCP\Files\Folder
+	 * @return Folder
+	 * @throws NoUserException
+	 * @throws NotPermittedException
+	 *
 	 * @since 8.2.0
 	 */
 	public function getUserFolder($userId);
-}
 
+	/**
+	 * Get a file or folder by fileid, inside a parent path
+	 *
+	 * @param int $id
+	 * @param string $path
+	 * @return Node[]
+	 *
+	 * @since 24.0.0
+	 */
+	public function getByIdInPath(int $id, string $path);
+}
